@@ -65,15 +65,15 @@ public enum GuardCipherExceptionCodes implements DisplayableOXExceptionCode {
     /**
      * The provided cipher service '%1$s' is unknown.
      */
-    UNKNOWN_CIPHER_SERVICE("The provided cipher service '%1$s' is unknown.", CATEGORY_ERROR, 1),
+    UNKNOWN_CIPHER_SERVICE("The provided cipher service '%1$s' is unknown.", GuardCipherExceptionMessages.UNKNOWN_CIPHER_SERVICE, CATEGORY_ERROR, 1),
     /**
      * The provided cipher algorithm '%1$s' is unknown.
      */
-    UNKNOWN_CIPHER_ALGORITHM("The provided cipher algorithm '%1$s' is unknown.", CATEGORY_ERROR, 2),
+    UNKNOWN_CIPHER_ALGORITHM("The provided cipher algorithm '%1$s' is unknown.", GuardCipherExceptionMessages.UNKNOWN_CIPHER_ALGORITHM, CATEGORY_ERROR, 2),
     /**
      * Invalid %1$s key length %2$s. Max is %3$s
      */
-    INVALID_KEY_LENGTH("Invalid %1$s key length %2$s. Maximum allowed key length on this system is %3$s", CATEGORY_CONFIGURATION, 3),
+    INVALID_KEY_LENGTH("Invalid %1$s key length %2$s. Maximum allowed key length on this system is %3$s", GuardCipherExceptionMessages.INVALID_KEY_LENGTH, CATEGORY_CONFIGURATION, 3),
 
     ;
 
