@@ -490,6 +490,11 @@ public enum GuardProperty {
      * Specifies the username for accessing the support API of OX Guard
      */
     supportApiUsername,
+    /**
+     * If authentication against middleware fails, Guard will delay and retry,
+     * allowing for possible delay in Hazelcast syncing session data.  Time in ms
+     */
+    sessionSyncDelay(3000),
     /**
      * Use TLS when delivering to the SMTP server when available
      */
@@ -544,6 +549,10 @@ public enum GuardProperty {
      * Defines the version of the 'Upgrader'
      */
     version(7, GuardProperty.PREFIX + "upgrader."),
+    /**
+     * Defines type of file storage.  File, sproxyd
+     */
+    fileStorageType("", GuardProperty.PREFIX + "storage.file."),
     /**
      * Defines the temporary upload directory for Guard Drive files in case of that the storage
      * type (com.openexchange.guard.storage.type) has been set to 'file'.
@@ -568,6 +577,12 @@ public enum GuardProperty {
      * Defaults to "s3.amazonaws.com" if not defined. Required if storage type is set to "s3".
      */
     endPoint(GuardProperty.EMPTY, GuardProperty.PREFIX + "storage.s3."),
+    /**
+     * Filestore name to use for S3 storage
+     * S3 configuration for the filestore is the same for other middleware S3 storage
+     * I.E. com.openexchange.filestore.s3.[filestore].endpoint etc
+     */
+    s3FileStore(GuardProperty.EMPTY, GuardProperty.PREFIX + "storage.s3."),
     /**
      * Configures the Amazon S3 region to use when creating new buckets. This value
      * is also used to pre-configure the client when no specific endpoint is set.
