@@ -124,13 +124,9 @@ public class DatabaseMaintenanceServiceImpl implements DatabaseMaintenanceServic
         try {
             db_id = nextId(configdbConnection);
 
-            String suffix = "?useUnicode=true&characterEncoding=UTF-8&autoReconnect=false&useUnicode=true&useServerPrepStmts=false&useTimezone=true&serverTimezone=UTC&connectTimeout=15000&socketTimeout=15000";
-            if (!connectionUrl.endsWith("/")) {
-                suffix = "/" + suffix;
-            }
             prep = configdbConnection.prepareStatement("INSERT INTO db_pool VALUES (?,?,?,?,?,?,?,?,?);");
             prep.setInt(1, db_id);
-            prep.setString(2, connectionUrl + suffix);
+            prep.setString(2, connectionUrl);
             prep.setString(3, "com.mysql.jdbc.Driver");
             prep.setString(4, mysqlUsername);
             prep.setString(5, mysqlPassword);
