@@ -55,8 +55,10 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Objects;
 import java.util.concurrent.ExecutionException;
 import org.apache.commons.lang.StringUtils;
+import org.osgi.framework.Bundle;
 import org.osgi.framework.FrameworkUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -236,7 +238,8 @@ public class GuardShardingServiceImpl implements GuardShardingService {
     public void updateShardSchema(final int shardId) throws OXException {
         final Connection shardConnection = guardDatabaseService.getWritableForShardNoTimeout(shardId);
 
-        BundleResourceAccessor bundleResourceAccessor = new BundleResourceAccessor(FrameworkUtil.getBundle(GuardDatabaseServiceImpl.class));
+        Bundle guardDatabaseServiceBundle = Objects.requireNonNull(FrameworkUtil.getBundle(GuardDatabaseServiceImpl.class), "Missing required GuardDatabaseService bundle");
+        BundleResourceAccessor bundleResourceAccessor = new BundleResourceAccessor(guardDatabaseServiceBundle);
         DBMigration dbMigration = new DBMigration(new DBMigrationConnectionProvider() {
 
             @Override
