@@ -51,6 +51,7 @@ package com.openexchange.guard.database.osgi;
 
 import java.sql.Connection;
 import java.sql.SQLException;
+import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.FrameworkUtil;
 import org.osgi.framework.ServiceReference;
@@ -67,6 +68,7 @@ import com.openexchange.guard.database.DatabaseMaintenanceService;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.database.dao.SchemaCandidate;
+import com.openexchange.guard.database.exception.GuardDatabaseExceptionCodes;
 import com.openexchange.guard.database.internal.DatabaseMaintenanceServiceImpl;
 import com.openexchange.guard.database.internal.GuardDatabaseServiceImpl;
 import com.openexchange.guard.database.internal.GuardShardingServiceImpl;
@@ -195,7 +197,11 @@ public class DBMigrationServiceTracker implements ServiceTrackerCustomizer<DBMig
     private void updateGuardSchema(DBMigrationExecutorService service, String guardDbSchema) throws OXException {
         final Connection guardConnection = guardDatabaseService.getWritableForGuardNoTimeout();
 
-        BundleResourceAccessor bundleResourceAccessor = new BundleResourceAccessor(FrameworkUtil.getBundle(GuardDatabaseServiceImpl.class));
+        Bundle dbBundle = FrameworkUtil.getBundle(GuardDatabaseServiceImpl.class);
+        if (dbBundle == null) {
+            throw GuardDatabaseExceptionCodes.DB_ERROR.create("Missing database bundle");
+        }
+        BundleResourceAccessor bundleResourceAccessor = new BundleResourceAccessor(dbBundle);
         DBMigration dbMigration = new DBMigration(new DBMigrationConnectionProvider() {
 
             @Override
