@@ -106,6 +106,14 @@ public interface EmailStorage {
      */
     Email getByEmail(String email) throws OXException;
 
+    /**
+     * Gets all existing mappings
+     *
+     * @return A list of all known emails
+     * @throws OXException
+     */
+    List<Email> getEmails() throws OXException;
+
     /**
      * Retrieves the e-mail address for the specified user
      *
@@ -135,17 +143,69 @@ public interface EmailStorage {
     int getHighestGuestId() throws OXException;
 
     /**
-     * Update a users email address
-     */
-    void updateEmail (String oldEmail, String newEmail) throws OXException;
-
-    /**
-     * Returns all users email for the given context id
-     * 
-     * @param cid The context-ID
-     * @param limit The limit of entries 
-     * @return A list of emails with max. size of lime
+     * Gets all emails that match the userid hash
+     *
+     * @param hu
+     * @return
      * @throws OXException
      */
-    List<Email> getForContext(int cid, int limit) throws OXException;
+    List<Email> getByHu(String hu) throws OXException;
+
+    /**
+     * Checks to see if Hu has been set up
+     *
+     * @return
+     * @throws OXException
+     */
+    boolean hasHu() throws OXException;
+
+    /**
+     * Simple count of number of email addresses in og_email table
+     *
+     * @return
+     * @throws OXException
+     */
+    int getCount() throws OXException;
+
+    /**
+     * Get count of missing user hashes
+     */
+    int getMissingHuCount() throws OXException;
+
+    /**
+     * Update the user hash
+     *
+     * @param email
+     * @param hu
+     * @throws OXException
+     */
+    boolean updateHu(String email, String hu) throws OXException;
+
+    /**
+     * Get a list of all emails with userid > 0
+     *
+     * @return
+     * @throws OXException
+     */
+    List<Email> getMissingHu(int limit) throws OXException;
+
+    /**
+     * Update a users email address
+     */
+    void updateEmail(String oldEmail, String newEmail) throws OXException;
+
+    /**
+     * Adds a new {@link EmailStorageListener}
+     *
+     * @param listener a listener which gets notified on storage changes
+     */
+    void addListener(EmailStorageListener listener);
+
+    /**
+     * Removes a new {@link EmailStorageListener}
+     *
+     * @param listener a listener which gets notified on storage changes
+     * @return True, if the listener was found and deleted, false otherwise
+     */
+    boolean removeListener(EmailStorageListener listener);
 }
