@@ -53,11 +53,17 @@ class EmailSql {
 
     static final String DELETE_ALL_FOR_USER_STMT = "DELETE FROM og_email WHERE id = ? AND cid = ?;";
     static final String SELECT_BY_EMAIL_STMT = "SELECT cid, id,email,db FROM og_email WHERE email = ?;";
-    static final String INSERT_OR_UPDATE_STMT = "INSERT INTO og_email (email, id, cid, db) VALUES (?, ?, ?, ?) ON DUPLICATE KEY UPDATE id = ?, cid = ?, db = ?";
+    static final String INSERT_OR_UPDATE_STMT = "INSERT INTO og_email (email, id, cid, db, hu) VALUES (?, ?, ?, ?, ?) ON DUPLICATE KEY UPDATE id = ?, cid = ?, db = ?";
     static final String SELECT_BY_USERID_STMT = "SELECT cid, id,email,db from og_email WHERE id = ? AND cid = ?";
     static final String SELECT_HIGHEST_GUEST_USERID_STMT = "SELECT MAX(ID) FROM og_email WHERE cid < 0";
     static final String DELETE_ALL_FOR_CONTEXT_STMT = "DELETE FROM og_email WHERE cid = ?";
     static final String SELECT_EMAIL = "SELECT mail from user WHERE cid = ? AND id = ?";
+    static final String SELECT_ALL_STMT = "SELECT cid, id,email,db FROM og_email;";
+    static final String SELECT_BY_HU = "SELECT cid, id, email, db FROM og_email WHERE hu = ?";
+    static final String CHECK_HU = "SELECT hu FROM og_email WHERE cid > 0 and hu IS NOT null";
+    static final String GET_COUNT = "SELECT COUNT(email) FROM og_email";
+    static final String GET_MISSING_HU_COUNT = "SELECT COUNT(email) FROM og_email WHERE cid > 0 AND hu IS null";
+    static final String UPDATE_HU = "UPDATE og_email SET hu = ? WHERE email = ?";
+    static final String FIND_MISSING_HU = "SELECT cid, id, email, db FROM og_email WHERE cid > 0 AND hu IS null";
     static final String UPDATE_EMAIL_ADDRESS = "UPDATE og_email SET email = ? WHERE email = ? LIMIT 1";
-    static final String GET_BY_CONTEXT = "SELECT cid, id, email,db from og_email WHERE cid = ? LIMIT ?";
 }
