@@ -56,16 +56,20 @@ import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.List;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.utils.DBUtils;
 import com.openexchange.guard.database.utils.GuardConnectionWrapper;
-import com.openexchange.guard.email.storage.exceptions.GuardEmailStorageExceptionCodes;
 import com.openexchange.guard.email.storage.ogEmail.Email;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
+import com.openexchange.guard.email.storage.ogEmail.EmailStorageListener;
 import com.openexchange.guard.email.storage.osgi.Services;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 
 public class EmailStorageImpl implements EmailStorage {
 
+    ArrayList<EmailStorageListener> listeners = new ArrayList<EmailStorageListener>();
+
     @Override
     public void insertOrUpdate(String email, int contextId, int userId, int dbShard) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
@@ -87,12 +91,13 @@ public class EmailStorageImpl implements EmailStorage {
             stmt.setInt(2, userId);
             stmt.setInt(3, contextId);
             stmt.setInt(4, dbShard);
-            stmt.setInt(5, userId);
-            stmt.setInt(6, contextId);
-            stmt.setInt(7, dbShard);
+            stmt.setString(5, CipherUtil.getEmailUserHash(email));
+            stmt.setInt(6, userId);
+            stmt.setInt(7, contextId);
+            stmt.setInt(8, dbShard);
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
         }
@@ -108,9 +113,14 @@ public class EmailStorageImpl implements EmailStorage {
             stmt = connection.prepareStatement(EmailSql.DELETE_ALL_FOR_USER_STMT);
             stmt.setInt(1, userId);
             stmt.setInt(2, contextId);
-            stmt.executeUpdate();
+            int deleted = stmt.executeUpdate();
+            if(deleted > 0) {
+                for(EmailStorageListener l : listeners) {
+                   l.deleted(userId, contextId);
+                }
+            }
         } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
@@ -126,9 +136,14 @@ public class EmailStorageImpl implements EmailStorage {
         try {
             stmt = connection.prepareStatement(EmailSql.DELETE_ALL_FOR_CONTEXT_STMT);
             stmt.setInt(1, contextId);
-            stmt.executeUpdate();
+            int deleted = stmt.executeUpdate();
+            if(deleted > 0) {
+                for(EmailStorageListener l : listeners) {
+                   l.deleted(contextId);
+                }
+            }
         } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
@@ -151,7 +166,7 @@ public class EmailStorageImpl implements EmailStorage {
                 return new Email(resultSet.getString("email"), resultSet.getInt("id"), resultSet.getInt("cid"), resultSet.getInt("db"));
             }
         } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -159,6 +174,7 @@ public class EmailStorageImpl implements EmailStorage {
         return null;
     }
 
+    @Override
     public List<Email> getById(int contextId, int userId) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
         Connection connection = guardDatabaseService.getReadOnlyForGuard();
@@ -177,7 +193,32 @@ public class EmailStorageImpl implements EmailStorage {
             }
             return ret;
         } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(resultSet, stmt);
+            guardDatabaseService.backReadOnlyForGuard(connection);
+        }
+    }
+
+    @Override
+    public List<Email> getByHu (String hu) throws OXException {
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+        Connection connection = guardDatabaseService.getReadOnlyForGuard();
+
+        PreparedStatement stmt = null;
+        ResultSet resultSet = null;
+        List<Email> ret = new ArrayList<Email>();
+        try {
+            stmt = connection.prepareStatement(EmailSql.SELECT_BY_HU);
+            stmt.setString(1, hu);
+            resultSet = stmt.executeQuery();
+
+            while (resultSet.next()) {
+                ret.add(new Email(resultSet.getString(3), resultSet.getInt(2), resultSet.getInt(1), resultSet.getInt(4)));
+            }
+            return ret;
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -201,7 +242,7 @@ public class EmailStorageImpl implements EmailStorage {
             }
             return max;
         } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -231,7 +272,7 @@ public class EmailStorageImpl implements EmailStorage {
                 email = resultSet.getString("mail");
             }
         } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -239,6 +280,141 @@ public class EmailStorageImpl implements EmailStorage {
         return email;
     }
 
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.email.storage.ogEmail.EmailStorage#getEmails()
+     */
+    @Override
+    public List<Email> getEmails() throws OXException {
+        List<Email> ret = new ArrayList<Email>();
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+        Connection connection = guardDatabaseService.getReadOnlyForGuard();
+
+        PreparedStatement stmt = null;
+        ResultSet resultSet = null;
+        try {
+            stmt = connection.prepareStatement(EmailSql.SELECT_ALL_STMT);
+            resultSet = stmt.executeQuery();
+
+            while (resultSet.next()) {
+                ret.add(new Email(resultSet.getString(3), resultSet.getInt(2), resultSet.getInt(1), resultSet.getInt(4)));
+            }
+            return ret;
+
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(resultSet, stmt);
+            guardDatabaseService.backReadOnlyForGuard(connection);
+        }
+    }
+
+    @Override
+    public boolean hasHu () throws OXException {
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+        Connection connection = guardDatabaseService.getReadOnlyForGuard();
+
+        PreparedStatement stmt = null;
+        ResultSet resultSet = null;
+        try {
+            stmt = connection.prepareStatement(EmailSql.CHECK_HU);
+            resultSet = stmt.executeQuery();
+
+            return resultSet.next();
+
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(resultSet, stmt);
+            guardDatabaseService.backReadOnlyForGuard(connection);
+        }
+    }
+
+    @Override
+    public int getCount () throws OXException {
+        return count(EmailSql.GET_COUNT);
+    }
+
+    @Override
+    public int getMissingHuCount () throws OXException {
+        return count(EmailSql.GET_MISSING_HU_COUNT);
+    }
+
+    private int count (String sql) throws OXException {
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+        Connection connection = guardDatabaseService.getReadOnlyForGuard();
+
+        PreparedStatement stmt = null;
+        ResultSet resultSet = null;
+        try {
+            stmt = connection.prepareStatement(sql);
+            resultSet = stmt.executeQuery();
+            if (resultSet.next()) {
+                return resultSet.getInt(1);
+            }
+            return 0;
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(resultSet, stmt);
+            guardDatabaseService.backReadOnlyForGuard(connection);
+        }
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.email.storage.ogEmail.EmailStorage#updateHu(java.lang.String, java.lang.String)
+     */
+    @Override
+    public boolean updateHu(String email, String hu) throws OXException {
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+        Connection connection = guardDatabaseService.getReadOnlyForGuard();
+
+        PreparedStatement stmt = null;
+        ResultSet resultSet = null;
+        try {
+            stmt = connection.prepareStatement(EmailSql.UPDATE_HU);
+            stmt.setString(1, hu);
+            stmt.setString(2, email);
+            stmt.execute();
+            return true;
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(resultSet, stmt);
+            guardDatabaseService.backReadOnlyForGuard(connection);
+        }
+
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.email.storage.ogEmail.EmailStorage#getMissingHu()
+     */
+    @Override
+    public List<Email> getMissingHu(int limit) throws OXException {
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+        Connection connection = guardDatabaseService.getReadOnlyForGuard();
+
+        PreparedStatement stmt = null;
+        ResultSet resultSet = null;
+        List<Email> ret = new ArrayList<Email>();
+        int count = 0;
+        try {
+            stmt = connection.prepareStatement(EmailSql.FIND_MISSING_HU);
+            resultSet = stmt.executeQuery();
+
+            while (resultSet.next() && count < limit) {
+                ret.add(new Email(resultSet.getString(3), resultSet.getInt(2), resultSet.getInt(1), resultSet.getInt(4)));
+                count++;
+            }
+            return ret;
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(resultSet, stmt);
+            guardDatabaseService.backReadOnlyForGuard(connection);
+        }
+    }
+
     /* (non-Javadoc)
      * @see com.openexchange.guard.email.storage.ogEmail.EmailStorage#updateEmail(java.lang.String, java.lang.String)
      */
@@ -256,7 +432,7 @@ public class EmailStorageImpl implements EmailStorage {
             stmt.execute();
             return;
         } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -264,28 +440,19 @@ public class EmailStorageImpl implements EmailStorage {
 
     }
 
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.email.storage.ogEmail.EmailStorage#addListener(com.openexchange.guard.email.storage.ogEmail.EmailStorageListener)
+     */
     @Override
-    public List<Email> getForContext(int cid, int limit) throws OXException {
-        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+    public void addListener(EmailStorageListener listener) {
+        this.listeners.add(listener);
+    }
 
-        List<Email> ret = new ArrayList<Email>();
-        Connection con = guardDatabaseService.getReadOnlyForGuard();
-        PreparedStatement stmt = null;
-        ResultSet resultSet = null;
-        try {
-            stmt = con.prepareStatement(EmailSql.GET_BY_CONTEXT);
-            stmt.setInt(1, cid);
-            stmt.setInt(2, limit);
-            resultSet = stmt.executeQuery();
-            while (resultSet.next()) {
-                ret.add(new Email(resultSet.getString(3), resultSet.getInt(2), resultSet.getInt(1), resultSet.getInt(4)));
-            }
-        } catch (SQLException e) {
-            throw GuardEmailStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
-        } finally {
-            DBUtils.closeSQLStuff(resultSet, stmt);
-            guardDatabaseService.backReadOnlyForGuard(con);
-        }
-        return ret;
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.email.storage.ogEmail.EmailStorage#removeListener(com.openexchange.guard.email.storage.ogEmail.EmailStorageListener)
+     */
+    @Override
+    public boolean removeListener(EmailStorageListener listener) {
+        return this.listeners.remove(listener);
     }
 }
