@@ -178,8 +178,6 @@ public class GuardGuestEMailMetadataServiceImpl implements GuardGuestEMailMetada
         } else {
             Email guest = guestUpgradeService.getGuestRecord(null, userId, contextId);
             if (guest != null) {
-                contextId = guest.getContextId();
-                userId = guest.getUserId();
                 shard = guest.getShardingId();
             }
         }
