@@ -219,7 +219,12 @@ public class GuardGuestServiceImpl implements GuardGuestService {
 
         //Fetching the full message if specified by the caller or if we do not have meta data yet
         //MimeMessage fullBody = fetchFull || metaData == null ? getMimeMessage(guestUser.getContextId(), itemId) : null;
-        InputStream fullBodyStream = fetchFull || metaData == null ? getMimeMessageInputStream(itemId) : null;
+        InputStream fullBodyStream = null;
+        try {
+            fullBodyStream = fetchFull || metaData == null ? getMimeMessageInputStream(itemId) : null;
+        } catch (OXException ex) {  // Not found or other retrieval issue
+            LOGGER.error("Error fetching email body", ex);
+        }
 
         if(metaData != null) {
             if (fullBodyStream != null && decrypt) {
@@ -265,7 +270,9 @@ public class GuardGuestServiceImpl implements GuardGuestService {
         }
         finally {
             try {
-                mail.close();
+                if (mail != null) {
+                    mail.close();
+                }
             } catch (IOException e) {
                 throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
             }
@@ -390,9 +397,11 @@ public class GuardGuestServiceImpl implements GuardGuestService {
 
                 GuardGuestEMailMetadataService metaDataService = getMetaDataServiceForUser(contextId, userId);
 
-                metaDataService.delete(
-                    guestFileStorage.getGuestShardIdFromPrefix(directoryPrefix),
-                    new GuardGuestEmailMetadata(fileCacheItem.getItemId()));
+                Integer shardId = guestFileStorage.getGuestShardIdFromPrefix(directoryPrefix);
+                if (shardId != null) {
+                    metaDataService.delete(shardId,
+                        new GuardGuestEmailMetadata(fileCacheItem.getItemId()));
+                }
             }
         }
     }
