@@ -156,16 +156,13 @@ public class HKPIndex {
 
                     logger.debug("IP in whitelist, checking against OX backend");
 
-                    GuardConfigurationService guardConfigurationService = Services.getService(GuardConfigurationService.class);
-                    String passwordFromAddress = guardConfigurationService.getProperty(GuardProperty.passwordFromAddress);
-
                     //Check and see if we can get public key from the backend if member; No guest and no HKP lookup;
                     RecipKeyService recipientKeyService = Services.getService(RecipKeyService.class);
                     RecipKey key = recipientKeyService.getInternalRecipKey(assertUnwantedCharacters(search));
                     if (key != null) {
                         //This will create a key for a requested user if it is an OX user; but not a guest
                         if(key.isNewKey() && !key.isGuest()) {
-                            key = Services.getService(AccountCreationService.class).createUserFor(key);
+                            Services.getService(AccountCreationService.class).createUserFor(key);
                         }
                         //Lookup the new created key
                         keyrings = pgpKeyService.getPublicKeyRing(assertUnwantedCharacters(search));
@@ -175,7 +172,7 @@ public class HKPIndex {
                 }
             }
         } else {  // Search by keyId
-        	search = normalizeSearch(search);
+            search = normalizeSearch(search);
 
             PGPPublicKeyRing resultKeyRing = null;
             if (search.length() > 8) {
