@@ -100,7 +100,6 @@ public class GuardKeys {
     private long keyid;
     private boolean current;
     private boolean inline;
-    private boolean encryptIncoming;
     private int version;
     private String language;
 
@@ -157,6 +156,14 @@ public class GuardKeys {
         privkey = encryptedPrivateKey;
     }
 
+    private PGPSecretKeyRing getSecretKeyRingInternal() {
+       if(keyring != null && publicKeyRing != null) {
+           //Use the public key material because it can contain additional user IDs, signatures, images, etc.
+           keyring = PGPSecretKeyRing.replacePublicKeys(keyring, publicKeyRing);
+       }
+       return keyring;
+    }
+
     /**
      * Sets the PGPSecretKeyRing
      *
@@ -176,7 +183,8 @@ public class GuardKeys {
     }
 
     public boolean hasPrivateKey() {
-        return this.keyring != null && keyring.getSecretKey() != null;
+        final PGPSecretKeyRing keyring = getSecretKeyRingInternal();
+        return keyring != null && keyring.getSecretKey() != null;
     }
 
     /**
@@ -250,7 +258,7 @@ public class GuardKeys {
     }
 
     /**
-     * Return the Public Key
+     * Return the Public Master Key
      *
      * @return
      */
@@ -282,11 +290,12 @@ public class GuardKeys {
     }
 
     /**
-     * Return the secret Key
+     * Return the secret master key
      *
-     * @return
+     * @return The secret master key
      */
     public PGPSecretKey getPGPSecretKey() {
+        final PGPSecretKeyRing keyring = getSecretKeyRingInternal();
         if (keyring == null) {
             return null;
         }
@@ -295,6 +304,7 @@ public class GuardKeys {
 
     public PGPSecretKey getPGPSigningKey() {
         //return PGPUtil.getSigningKey(keyring);
+        final PGPSecretKeyRing keyring = getSecretKeyRingInternal();
         Iterator<PGPSecretKey> it = keyring.getSecretKeys();
         PGPSecretKey toreturn = null;
         while (it.hasNext()) {
@@ -309,7 +319,7 @@ public class GuardKeys {
     }
 
     public PGPSecretKeyRing getPGPSecretKeyRing() {
-        return keyring;
+        return getSecretKeyRingInternal();
     }
 
     /**
@@ -319,6 +329,7 @@ public class GuardKeys {
      * @throws OXException
      */
     public String getEncodedPGPSecret() throws OXException {
+        final PGPSecretKeyRing keyring = getSecretKeyRingInternal();
         if (keyring == null) {
             return null;
         }
@@ -546,9 +557,4 @@ public class GuardKeys {
         }
         return false;
     }
-
-    public void setEncryptIncoming (boolean encrypt) {
-        this.encryptIncoming = encrypt;
-    }
-
 }
