@@ -51,6 +51,7 @@ package com.openexchange.guard.keymanagement.commons.export;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.nio.charset.StandardCharsets;
 import java.util.Iterator;
 import java.util.Objects;
 import org.bouncycastle.bcpg.ArmoredOutputStream;
@@ -99,7 +100,7 @@ public class KeyExportUtil {
             bout.close();
             out.close();
 
-            return (new String(out.toByteArray()));
+            return (new String(out.toByteArray(), StandardCharsets.UTF_8));
         } catch (IOException e) {
             throw KeysExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
