@@ -49,6 +49,7 @@
 
 package com.openexchange.guard.keymanagement.commons.trust;
 
+import com.openexchange.guard.configuration.GuardProperty;
 
 /**
  * {@link GuardKeySources} defines a set of default Guard key sources ({@link KeySource}).
@@ -58,18 +59,34 @@ package com.openexchange.guard.keymanagement.commons.trust;
  */
 public class GuardKeySources {
 
+    /**
+     * An Unknown source
+     */
+    public static KeySource UNKNOWN;
+
     /**
      * The {@link KeySource} for a regular user's key pair.
      */
-    public final static KeySource GUARD = new KeySource("GUARD_KEY_PAIR", 5);
+    public static KeySource GUARD;
 
     /**
      * The {@link KeySource} for a public key uploaded by a user to {@link OGPGPKeysStorage}.
      */
-    public final static KeySource GUARD_USER_UPLOADED = new KeySource("GUARD_USER_UPLOADED",4);
+    public static KeySource GUARD_USER_UPLOADED;
 
     /**
      * Key was uploaded by another user in the same context ID and shared
      */
-    public final static KeySource GUARD_USER_SHARED = new KeySource("GUARD_USER_SHARED", 3);
+    public static KeySource GUARD_USER_SHARED;
+
+    /**
+     * Initializes the key source values
+     * @param keySourceFactory
+     */
+    public static void initialize(KeySourceFactory keySourceFactory) {
+        UNKNOWN = keySourceFactory.create("UNKNOWN", 0);
+        GUARD = keySourceFactory.create("GUARD_KEY_PAIR", GuardProperty.trustLevelGuard);
+        GUARD_USER_UPLOADED = keySourceFactory.create("GUARD_USER_UPLOADED",GuardProperty.trustLevelGuardUserUploaded);
+        GUARD_USER_SHARED = keySourceFactory.create("GUARD_USER_SHARED", GuardProperty.trustLevelGuardUserShared);
+    }
 }
