@@ -238,6 +238,10 @@ public final class PGPUtil {
                 return ("Revoke");
             case PGPSignature.SUBKEY_REVOCATION:
                 return ("Sub revoke");
+            case PGPSignature.SUBKEY_BINDING:
+                return ("Subkey Binding");
+            case PGPSignature.PRIMARYKEY_BINDING:
+                return ("Primary Binding");
         }
         return ("");
     }
