@@ -50,6 +50,7 @@
 package com.openexchange.guard.keymanagement.services.impl;
 
 import java.io.UnsupportedEncodingException;
+import java.nio.charset.StandardCharsets;
 import java.security.KeyFactory;
 import java.security.NoSuchAlgorithmException;
 import java.security.PrivateKey;
@@ -83,6 +84,8 @@ import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
 import com.openexchange.guard.keymanagement.services.PasswordChangeService;
 import com.openexchange.guard.keymanagement.services.RevocationReason;
+import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardKeyCreationExceptionCodes;
+import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardMasterKeyExceptionCodes;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
@@ -219,6 +222,20 @@ public class GuardKeyServiceImpl implements GuardKeyService {
         return null;
     }
 
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.keymanagement.services.GuardKeyService#getKeysBySubKeyId(java.lang.String, long)
+     */
+    @Override
+    public GuardKeys getKeysBySubKeyId(String email, long keyId) throws OXException {
+        EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
+        Email emailMapping = ogEmailStorage.getByEmail(email);
+        if (emailMapping != null) {
+            return getKeysBySubKeyId(emailMapping.getUserId(), emailMapping.getContextId(), keyId);
+        }
+        return null;
+    }
+
+
     /* (non-Javadoc)
      * @see com.openexchange.guard.keymanagement.services.GuardKeyService#getAllKeys(int, int)
      */
@@ -253,7 +270,9 @@ public class GuardKeyServiceImpl implements GuardKeyService {
         keyTableStorage.insert(key, userCreated, shard);
         //retrieve the created key in order to get the userid which was created while inserting
         ret = keyTableStorage.getKeyForEmailAndContext(key.getEmail(), key.getUserid(), key.getContextid(), shard);
-
+        if (ret == null) {
+            throw GuardKeyCreationExceptionCodes.KEY_CREATION_ERROR.create("Problem retrieving key from table storage after creation");
+        }
         //Store key mappings
         if (ret.getUserid() > 0) {
             //Adding the new key to the email mapping storage
@@ -372,7 +391,13 @@ public class GuardKeyServiceImpl implements GuardKeyService {
                 GuardMasterKeyService masterKeyService = Services.getService(GuardMasterKeyService.class);
                 GuardCipherService rsaCipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.RSA);
                 GuardKeys masterKeys = ogKeyTableStorage.getGuardDaemonKey();
+                if (masterKeys == null) {
+                    throw GuardMasterKeyExceptionCodes.UNABLE_TO_RETIREVE_MASTER_PASSWORD.create();
+                }
                 PrivateKey privateKey = decryptPrivateKey(masterKeys.getEncodedPrivate(), masterKeyService.getMasterKey().getMC(), masterKeys.getSalt());
+                if (privateKey == null) {
+                    throw new Exception("Bad master key");
+                }
                 String encrhash = rsaCipherService.decrypt(currentKey.getRecovery(), privateKey);
                 if (Strings.isEmpty(encrhash)) {
                     LOG.error("Unable to decode master key.  Possible corrupted data");
@@ -508,7 +533,7 @@ public class GuardKeyServiceImpl implements GuardKeyService {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
         // for private keys use PKCS8EncodedKeySpec; for public keys use X509EncodedKeySpec
-        PKCS8EncodedKeySpec ks = new PKCS8EncodedKeySpec(Base64.decode(new String(decoded)));
+        PKCS8EncodedKeySpec ks = new PKCS8EncodedKeySpec(Base64.decode(new String(decoded, StandardCharsets.UTF_8)));
 
         try {
             KeyFactory kf = KeyFactory.getInstance("RSA");
@@ -568,11 +593,11 @@ public class GuardKeyServiceImpl implements GuardKeyService {
      * @see com.openexchange.guard.keymanagement.services.GuardKeyService#setCurrentKey(int, int, com.openexchange.guard.keymanagement.commons.GuardKeys)
      */
     @Override
-    public void setCurrentKey(int userId, int contextId, GuardKeys key) throws OXException {
+    public void setCurrentKey(GuardKeys key) throws OXException {
         key = Objects.requireNonNull(key, "key must not be null");
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
         //Removing the current flag from all keys
-        ogKeyTableStorage.unsetCurrentFlag(userId, contextId);
+        ogKeyTableStorage.unsetCurrentFlag(key.getUserid(), key.getContextid());
         //Setting the current flag for the given key
         ogKeyTableStorage.setCurrentKey(key);
     }
@@ -617,6 +642,10 @@ public class GuardKeyServiceImpl implements GuardKeyService {
         //Getting the private key used for singing
         PGPPrivateKey privateKey = null;
         try {
+            PGPSecretKey secretKey = key.getPGPSecretKey();
+            if (secretKey == null) {
+                throw KeysExceptionCodes.NO_KEY_ERROR.create();
+            }
             privateKey = PGPUtil.decodePrivate(key.getPGPSecretKey(), password, key.getSalt());
         } catch (PGPException e) {
             throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
