@@ -1,13 +1,11 @@
 package com.openexchange.guard.keymanagement.services.impl;
 import java.security.PrivateKey;
 import java.util.Date;
-
 import org.bouncycastle.openpgp.PGPEncryptedData;
 import org.bouncycastle.openpgp.PGPException;
 import org.bouncycastle.openpgp.PGPSecretKeyRing;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-
 import com.google.gson.JsonObject;
 import com.google.gson.JsonPrimitive;
 import com.openexchange.exception.OXException;
@@ -25,10 +23,12 @@ import com.openexchange.guard.keymanagement.commons.exceptions.KeysExceptionCode
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
 import com.openexchange.guard.keymanagement.services.PasswordChangeService;
-import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardCryptoExceptionCodes;
 import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardChangePasswordExceptionCodes;
+import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardCryptoExceptionCodes;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
+import com.openexchange.guard.secondfactor.SecondFactorService;
 import com.openexchange.guard.session.GuardSessionService;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 public class PasswordChangeServiceImpl implements PasswordChangeService {
@@ -36,7 +36,7 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
     private static final Logger LOG = LoggerFactory.getLogger(PasswordChangeService.class);
 
     @Override
-    public String changePassword (int userid, int cid, String email, String oldpass, String newpass, String question, String answer, String sessionId) throws OXException {
+    public String changePassword (int userid, int cid, String userEmail, String oldpass, String newpass, String question, String answer, String pin, String sessionId) throws OXException {
         JsonObject returnJson = new JsonObject();
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
         GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
@@ -58,12 +58,25 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         GuardKeys keys = keyService.getKeys(userid, cid);
         if (keys == null) {
-            returnJson.addProperty("auth", "Key not found");
-            throw GuardCoreExceptionCodes.KEY_NOT_FOUND.create();
+            // Keys not found.  Possible Guest user
+            OXUserService userService = Services.getService(OXUserService.class);
+            if (userService.isGuest(userid, cid)) {  // Make sure guest.  If so, try to load keys based on email
+                keys = keyService.getKeys(userEmail);
+            }
+            if (keys == null) {
+                returnJson.addProperty("auth", "Key not found");
+                throw GuardCoreExceptionCodes.KEY_NOT_FOUND.create();
+            }
+        }
+        boolean hasPin = false;
+        SecondFactorService secondFactor = Services.getService(SecondFactorService.class);
+        if (secondFactor.hasSecondFactor(keys.getUserid(), keys.getContextid())) {
+            hasPin = true;
+            secondFactor.verifySecondFactor(keys.getUserid(), keys.getContextid(), pin);
         }
         String oldQuestion = keys.getQuestion();
         if (oldpass == null || oldpass.equals("")) {
-            keys = changeTemporaryPassword(userid, cid, newpass);
+            keys = changeTemporaryPassword(keys.getUserid(), keys.getContextid(), newpass);
         } else {
             keys = changePassword(oldpass, newpass, keys);
         }
@@ -73,27 +86,30 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
             antiabuse.addBad(sessionId);
             throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
         } else {
+            if (hasPin) {
+                secondFactor.removeSecondFactorIfSingleUse(keys.getUserid(), keys.getContextid());
+            }
             String recovery = "";
             boolean recoveryAvail = false;
             KeyRecoveryService recoveryService = Services.getService(KeyRecoveryService.class);
-            if (recoveryService.checkCreateRecovery(cid, userid)) {
+            if (recoveryService.checkCreateRecovery(keys.getContextid(), keys.getUserid())) {
                 recoveryAvail = true;
                 recovery  = recoveryService.createRecovery(keys, newpass);
             }
             Date now = new Date();
             keys.setLastup(new java.sql.Date(now.getTime()));
-            keyService.updateKeys(userid, cid, keys, recovery, false);
+            keyService.updateKeys(keys.getUserid(), keys.getContextid(), keys, recovery, false);
 
             if (cid < 0) {  // Guests have question/answer to store
                 if (question.equals("") && !answer.equals("")) {
                     question = "default";
                 }
                 if (answer != null && !answer.equals("")) {
-                    keyService.storeQuestion(userid, cid, question, answer);
+                    keyService.storeQuestion(keys.getUserid(), keys.getContextid(), question, answer);
                 }
             } else {
                 if (oldQuestion == null || ((answer != null) && (answer.length() > 1))) {
-                    keyService.storeQuestion(userid, cid, question, answer);
+                    keyService.storeQuestion(keys.getUserid(), keys.getContextid(), question, answer);
                 }
             }
 
@@ -105,9 +121,9 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
             }
             // The enrypted auth data
             JsonObject json = new JsonObject();
-            json.addProperty("user_id", userid);
-            json.addProperty("cid", cid);
-            json.addProperty("email", email);
+            json.addProperty("user_id", keys.getUserid());
+            json.addProperty("cid", keys.getContextid());
+            json.addProperty("email", userEmail);
             json.add("encr_password", new JsonPrimitive(newpass));
             GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_GCM);
             returnJson.addProperty("auth", cipherService.encrypt(json.toString(), token));
