@@ -68,6 +68,7 @@ import com.openexchange.guard.keymanagement.commons.OGPGPKey;
 import com.openexchange.guard.keymanagement.commons.OGPGPKeyRing;
 import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
 import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
+import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardKeyImportExceptionCodes;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
 import com.openexchange.guard.ratifier.GuardRatifierService;
@@ -110,7 +111,7 @@ public class PublicExternalKeyServiceImpl implements PublicExternalKeyService {
         return null;
     }
 
-    private void importPublicKeyRing(int userId, int contextId, PGPPublicKeyRing publicKeyRing) throws OXException {
+    private OGPGPKeyRing importPublicKeyRing(int userId, int contextId, PGPPublicKeyRing publicKeyRing) throws OXException {
 
         ArrayList<String> keyEmailIdentities = new ArrayList<String>();
         ArrayList<String> keyHexIds = new ArrayList<String>();
@@ -134,15 +135,22 @@ public class PublicExternalKeyServiceImpl implements PublicExternalKeyService {
                 try {
                     guardRatifierService.validate(keyEmailIdentity);
                 } catch (OXException e) {
-                    continue;
+                    //The user id is not a RFC conform email address.
+                    throw GuardKeyImportExceptionCodes.NO_SUCH_USERID_IN_KEY_ERROR.create();
                 }
 
                 //Adding the new uploaded key to the storage
                 String asciiData = KeyExportUtil.export(publicKeyRing);
                 OGPGPKeysStorage ogpgpKeysStorage = Services.getService(OGPGPKeysStorage.class);
                 ogpgpKeysStorage.insertOrUpdate(userId, contextId, keyEmailIdentity, keyHexIds, asciiData);
+
             }
+            final boolean isInline = false;
+            final int shareLevel = 0;
+            final boolean owned = true;
+            return new OGPGPKeyRing(OGPGPKey.keyIdsAsString(keyHexIds), publicKeyRing, isInline, shareLevel, owned);
         }
+        return null;
     }
 
     /*
@@ -151,11 +159,46 @@ public class PublicExternalKeyServiceImpl implements PublicExternalKeyService {
      * @see com.openexchange.guard.keymanagement.services.PublicExternalKeyService#importPublicKeyRing(org.bouncycastle.openpgp.PGPPublicKeyRing)
      */
     @Override
-    public void importPublicKeyRing(int userId, int contextId, PGPPublicKeyRing... publicKeyRings) throws OXException {
+    public List<OGPGPKeyRing> importPublicKeyRing(int userId, int contextId, PGPPublicKeyRing... publicKeyRings) throws OXException {
         publicKeyRings = Objects.requireNonNull(publicKeyRings, "publicKeyRing must not be null");
+        List<OGPGPKeyRing> importedKeysRings = new ArrayList<OGPGPKeyRing>();
         for (PGPPublicKeyRing publicKeyRing : publicKeyRings) {
-            importPublicKeyRing(userId, contextId, publicKeyRing);
+            OGPGPKeyRing imported = importPublicKeyRing(userId, contextId, publicKeyRing);
+            if(imported != null) {
+                importedKeysRings.add(imported);
+            }
         }
+        return importedKeysRings;
+    }
+
+    /**
+     * Summarize the list of keys by ids
+     *
+     * @param keyEntries, full list of keys
+     * @param userId of the user currently pulling the keys
+     * @param contextId of the user
+     * @return
+     * @throws OXException
+     */
+    private List<OGPGPKeyRing> normalize(List<OGPGPKey> keyEntries, int userId, int contextId) throws OXException {
+        List<OGPGPKeyRing> ret = new ArrayList<OGPGPKeyRing>();
+        try {
+            ArrayList<String> processedIds = new ArrayList<String>();
+            for (OGPGPKey ogpgpKey : keyEntries) {
+                //summarize by ids so that each key-ring is treated as unique
+                String ids = ogpgpKey.getKeyIdsAsString();
+                if (!processedIds.contains(ids)) {
+                    boolean owned = (ogpgpKey.getUserId() == userId) && (ogpgpKey.getContextId() == contextId);  // Establish if this key is owned
+                    ret.add(new OGPGPKeyRing(ids, PGPPublicKeyRingFactory.create(ogpgpKey.getPublicPGPAscData()), ogpgpKey.isInline(),
+                        ogpgpKey.getShareLevel(), owned));
+                    processedIds.add(ids);
+                }
+            }
+        } catch (IOException e) {
+            throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
+        }
+
+        return ret;
     }
 
     /*
@@ -182,25 +225,18 @@ public class PublicExternalKeyServiceImpl implements PublicExternalKeyService {
      */
     @Override
     public List<OGPGPKeyRing> get(int userId, int contextId) throws OXException {
-        List<OGPGPKeyRing> ret = new ArrayList<OGPGPKeyRing>();
         //The storage returns a key entry for each email of the key-ring
         List<OGPGPKey> keyEntries = pgpKeysStorage.getForUser(userId, contextId);
-        //..we return a normalized representation here. Group by "ids".
-        try {
-            ArrayList<String> processedIds = new ArrayList<String>();
-            for (OGPGPKey ogpgpKey : keyEntries) {
-                //summarize by ids so that each key-ring is treated as unique
-                String ids = ogpgpKey.getKeyIdsAsString();
-                if (!processedIds.contains(ids)) {
-                    ret.add(new OGPGPKeyRing(ids, PGPPublicKeyRingFactory.create(ogpgpKey.getPublicPGPAscData()), ogpgpKey.isInline(), ogpgpKey.getShareLevel()));
-                    processedIds.add(ids);
-                }
-            }
-        } catch (IOException e) {
-            throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
-        }
+        return normalize(keyEntries, userId, contextId);
+    }
 
-        return ret;
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.keymanagement.services.PublicExternalKeyService#get(int, int, java.util.List)
+     */
+    @Override
+    public List<OGPGPKeyRing> get(int userId, int contextId, List<String> emails) throws OXException {
+        List<OGPGPKey> keyEntries = pgpKeysStorage.getForUserByEmail(userId, contextId, emails);
+        return normalize(keyEntries, userId, contextId);
     }
 
     /* (non-Javadoc)
