@@ -73,14 +73,16 @@ import com.openexchange.guard.keymanagement.services.lookup.RecipKeyLookupStrate
 public class RecipKeyServiceImpl implements RecipKeyService {
 
     private final GuardKeyService guardKeyService;
+    private final int remoteTimeout;
 
     /**
      * Initializes a new {@link RecipKeyServiceImpl}.
      *
      * @param guardKeyService The {@link GuardKeyService} to use
      */
-    public RecipKeyServiceImpl(GuardKeyService guardKeyService) {
+    public RecipKeyServiceImpl(GuardKeyService guardKeyService, int remoteTimeout) {
         this.guardKeyService = guardKeyService;
+        this.remoteTimeout = remoteTimeout;
     }
 
     /**
@@ -109,12 +111,12 @@ public class RecipKeyServiceImpl implements RecipKeyService {
     @Override
     public RecipKey getRecipKey(RecipKeyLookupStrategy lookupStrategy, String email) throws OXException {
         lookupStrategy = Objects.requireNonNull(lookupStrategy, "lookupStrategy must not be null");
-        return lookupStrategy.lookup(email);
+        return lookupStrategy.lookup(email, remoteTimeout);
     }
 
     @Override
     public RecipKey getRecipKey(int senderUserId, int senderContextId, String email) throws OXException {
-        return new DefaultRecipKeyLookupStrategy(senderUserId, senderContextId, createHKPClientToken(senderUserId, senderContextId)).lookup(email);
+        return new DefaultRecipKeyLookupStrategy(senderUserId, senderContextId, createHKPClientToken(senderUserId, senderContextId)).lookup(email, remoteTimeout);
     }
 
     /* (non-Javadoc)
@@ -122,6 +124,6 @@ public class RecipKeyServiceImpl implements RecipKeyService {
      */
     @Override
     public RecipKey getInternalRecipKey(String email) throws OXException {
-        return new InternalRecipKeyLookupStrategy().lookup(email);
+        return new InternalRecipKeyLookupStrategy().lookup(email, remoteTimeout);
     }
 }
\ No newline at end of file
