@@ -50,12 +50,14 @@
 package com.openexchange.guard.keymanagement.services.impl.lookup;
 
 import java.util.Collection;
+import java.util.Iterator;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.hkpclient.services.HKPClientService;
 import com.openexchange.guard.hkpclient.services.RemoteKeyResult;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
+import com.openexchange.guard.keymanagement.services.lookup.AbstractRecipKeyLookupStrategy;
 import com.openexchange.guard.keymanagement.services.lookup.RecipKeyLookupStrategy;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
@@ -65,7 +67,7 @@ import com.openexchange.pgp.keys.tools.PGPKeysUtil;
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v2.6.0
  */
-public class HKPRecipKeyLookupStrategy implements RecipKeyLookupStrategy {
+public class HKPRecipKeyLookupStrategy extends AbstractRecipKeyLookupStrategy {
 
     private final String hkpClientToken;
 
@@ -101,7 +103,13 @@ public class HKPRecipKeyLookupStrategy implements RecipKeyLookupStrategy {
     public RecipKey lookup(String email, int timeout) throws OXException {
         Collection<RemoteKeyResult> results = Services.getService(HKPClientService.class).find(hkpClientToken, email, timeout);
         if(results != null && !results.isEmpty()) {
-            return toRecipKey(email, results.iterator().next());
+            Iterator<RemoteKeyResult> it = results.iterator();
+            while (it.hasNext()) {
+                RemoteKeyResult result = it.next();
+                if (result != null && hasValidEncryptionKey(result.getRing())) {
+                    return toRecipKey(email, result);
+                }
+            }
         }
         return null;
     }
