@@ -218,7 +218,11 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
         registerService(PublicExternalKeyService.class, publicExternalKeyService);
 
         //Service for getting keys per contact
-        registerService(ContactKeyService.class, new ContactKeyServiceImpl(keyService, publicExternalKeyService, getService(ContactService.class)));
+        registerService(ContactKeyService.class,
+            new ContactKeyServiceImpl(keyService,
+                publicExternalKeyService,
+                getService(ContactService.class),
+                getService(GuardRatifierService.class)));
 
         //Service for importing client created, custom keys
         registerService(KeyImportService.class, new KeyImportServiceImpl(keyRecoveryService,keyService,
