@@ -103,6 +103,16 @@ public interface GuardKeyService {
      */
     GuardKeys getKeysBySubKeyId(int id, int cid, long keyId) throws OXException;
 
+    /**
+     * Gets a specific {@link GuardKeys} by a master- or sub-key id
+     *
+     * @param email The user's email
+     * @param keyId The ID of the key. Sub key IDs are considered.
+     * @return The {@link GuardKeys}
+     * @throws OXException
+     */
+    GuardKeys getKeysBySubKeyId(String email, long keyId) throws OXException;
+
     /**
      * Gets the key for the user with the specified e-mail address
      *
@@ -302,12 +312,10 @@ public interface GuardKeyService {
     /**
      * Sets the current key for a user.
      *
-     * @param userId the ID of the user
-     * @param contextId the context of the user.
      * @param key The key to mark as current
      * @throws OXException
      */
-    void setCurrentKey(int userId, int contextId, GuardKeys key) throws OXException;
+    void setCurrentKey(GuardKeys key) throws OXException;
 
     /**
      * Adds a new user-ID to the key
