@@ -732,6 +732,27 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         }
     }
 
+    @Override
+    public void updateLocale(GuardKeys key) throws OXException {
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+
+        GuardConnectionWrapper connectionWrapper = guardDatabaseService.getWritable(key.getUserid(), key.getContextid(), 0);
+
+        PreparedStatement stmt = null;
+        try {
+            stmt = connectionWrapper.getConnection().prepareStatement(KeyTableSql.UPDATE_LOCALE);
+            stmt.setString(1, key.getLanguage());
+            stmt.setInt(2, key.getContextid());
+            stmt.setInt(3, key.getUserid());
+            stmt.executeUpdate();
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(stmt);
+            guardDatabaseService.backWritable(connectionWrapper);
+        }
+    }
+
     @Override
     public void updateSettingsForUser(int userId, int contextId, String settings) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
