@@ -51,7 +51,7 @@ package com.openexchange.guard.keymanagement.storage.impl.pgpkeys;
 
 class PGPKeysSql {
 
-    static final String SELECT_BY_EMAIL_STMT = "SELECT id,email,hexid, cid, local,keyid FROM PGPKeys WHERE email = ? AND cid > 0";
+    static final String SELECT_BY_EMAIL_STMT = "SELECT id,email,hexid, cid, local,keyid FROM PGPKeys WHERE email = ? AND cid >= 0";
     static final String SELECT_BY_HEXID_STMT = "SELECT id,email,hexid, cid, local,keyid FROM PGPKeys WHERE hexid = ?";
     static final String SELECT_BY_ID_STMT = "SELECT id,email,hexid, cid, local,keyid FROM PGPKeys WHERE id = ?";
     static final String SELECT_BY_IDS_STMT = "SELECT id, email, hexid, cid, local, keyid FROM PGPKeys WHERE id IN ({@VALUES});";
