@@ -57,13 +57,16 @@ import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Objects;
 import org.bouncycastle.openpgp.PGPPublicKey;
-import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.utils.DBUtils;
+import com.openexchange.guard.keymanagement.commons.CachedKey;
 import com.openexchange.guard.keymanagement.commons.exceptions.KeysExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
+import com.openexchange.guard.keymanagement.commons.trust.KeySource;
+import com.openexchange.guard.keymanagement.commons.trust.KeySourceFactory;
 import com.openexchange.guard.keymanagement.storage.RemoteKeyCacheStorage;
 import com.openexchange.guard.keymanagement.storage.impl.osgi.Services;
 import com.openexchange.guard.ratifier.GuardRatifierService;
@@ -71,6 +74,30 @@ import com.openexchange.pgp.keys.parsing.PGPPublicKeyRingFactory;
 
 public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
 
+    private static final String RING_COLUMN = "ring";
+    private static final String KEYSOURCE_COLUMN = "keysource";
+    private final KeySourceFactory keySourceFactory;
+
+    /**
+     * Initializes a new {@link RemoteKeyCacheStorageImpl}.
+     * 
+     * @param keySourceFactory The {@link KeySourceFactory} service
+     */
+    public RemoteKeyCacheStorageImpl(KeySourceFactory keySourceFactory) {
+        this.keySourceFactory = Objects.requireNonNull(keySourceFactory, "keySourceFactory must not be null");
+    }
+
+    private KeySource toKeySource(ResultSet resultSet) throws SQLException, OXException {
+        final String keySourceName = resultSet.getString(KEYSOURCE_COLUMN);
+        return keySourceFactory.create(keySourceName);
+    }
+
+    private CachedKey toCachedKey(ResultSet resultSet) throws IOException, SQLException, OXException {
+        return new CachedKey(
+            PGPPublicKeyRingFactory.create(resultSet.getString(RING_COLUMN)),
+            toKeySource(resultSet));
+    }
+
     @Override
     public int deleteOld(int days) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
@@ -96,7 +123,7 @@ public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
     }
 
     @Override
-    public void insert(PGPPublicKeyRing keyRing) throws OXException {
+    public void insert(CachedKey cachedKey) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
         Connection connection = guardDatabaseService.getWritableForGuard();
 
@@ -105,15 +132,15 @@ public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
             connection.setAutoCommit(false);
             stmt = connection.prepareStatement(RemoteKeyCacheSql.INSERT_RING_DATA_STMT);
 
-            String keyRingAsc = KeyExportUtil.export(keyRing);
-            stmt.setLong(1, keyRing.getPublicKey().getKeyID());
+            String keyRingAsc = KeyExportUtil.export(cachedKey.getPublicKeyRing());
+            stmt.setLong(1, cachedKey.getPublicKeyRing().getPublicKey().getKeyID());
             stmt.setString(2, keyRingAsc);
             stmt.setString(3, keyRingAsc);
             stmt.executeUpdate();
 
             //Storing each identity related to the key ring
-            Iterator<String> ids = keyRing.getPublicKey().getUserIDs();
-            Long refid = keyRing.getPublicKey().getKeyID();
+            Iterator<String> ids = cachedKey.getPublicKeyRing().getPublicKey().getUserIDs();
+            Long refid = cachedKey.getPublicKeyRing().getPublicKey().getKeyID();
             while (ids.hasNext()) {
                 String email = ids.next().trim();
                 if (email.contains("@")){  // make sure has email address (Bug 45195)
@@ -126,7 +153,7 @@ public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
                     GuardRatifierService validatorService = Services.getService(GuardRatifierService.class);
                     validatorService.validate(email);
 
-                    Iterator<PGPPublicKey> keys = keyRing.getPublicKeys();
+                    Iterator<PGPPublicKey> keys = cachedKey.getPublicKeyRing().getPublicKeys();
                     while (keys.hasNext()) {
                         PGPPublicKey key = keys.next();
                         if (!key.hasRevocation()) {
@@ -138,7 +165,8 @@ public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
                                 stmt2.setLong(1, key.getKeyID());
                                 stmt2.setString(2, email);
                                 stmt2.setLong(3, refid);
-                                stmt2.setLong(4, refid);
+                                stmt2.setString(4, cachedKey.getKeySource().getName());
+                                stmt2.setLong(5, refid);
                                 stmt2.executeUpdate();
                             } finally {
                                 DBUtils.closeSQLStuff(stmt2);
@@ -160,7 +188,7 @@ public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
     }
 
     @Override
-    public List<PGPPublicKeyRing> getByEmail(String email) throws OXException {
+    public List<CachedKey> getByEmail(String email) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
         Connection connection = guardDatabaseService.getReadOnlyForGuard();
 
@@ -171,9 +199,9 @@ public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
             stmt.setString(1, email);
 
             resultSet = stmt.executeQuery();
-            ArrayList<PGPPublicKeyRing> ret = new ArrayList<PGPPublicKeyRing>();
+            ArrayList<CachedKey> ret = new ArrayList<CachedKey>();
             while (resultSet.next()) {
-                ret.add(PGPPublicKeyRingFactory.create(resultSet.getString("ring")));
+                ret.add(toCachedKey(resultSet));
             }
             return ret;
         } catch (SQLException e) {
@@ -187,7 +215,7 @@ public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
     }
 
     @Override
-    public PGPPublicKeyRing getByID(Long id) throws OXException {
+    public CachedKey getByID(Long id) throws OXException {
     	GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
         Connection connection = guardDatabaseService.getReadOnlyForGuard();
 
@@ -198,7 +226,7 @@ public class RemoteKeyCacheStorageImpl implements RemoteKeyCacheStorage {
             stmt.setLong(1, id);
             resultSet = stmt.executeQuery();
             if (resultSet.next()) {
-            	return PGPPublicKeyRingFactory.create(resultSet.getString("ring"));
+            	return toCachedKey(resultSet);
             }
             return null;
         } catch (SQLException e) {
