@@ -419,4 +419,11 @@ public interface KeyTableStorage {
      * @throws OXException
      */
     void updateMisc(GuardKeys key, String misc) throws OXException;
+
+    /**
+     * Updates the locale for a key
+     * @param key
+     * @throws OXException
+     */
+    void updateLocale(GuardKeys key) throws OXException;
 }
