@@ -54,11 +54,11 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Comparator;
-import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 import java.util.TreeSet;
+import org.bouncycastle.bcpg.attr.ImageAttribute;
 import org.bouncycastle.bcpg.sig.RevocationReasonTags;
 import org.bouncycastle.openpgp.PGPEncryptedData;
 import org.bouncycastle.openpgp.PGPException;
@@ -74,7 +74,6 @@ import org.bouncycastle.openpgp.PGPSignatureSubpacketGenerator;
 import org.bouncycastle.openpgp.PGPSignatureSubpacketVector;
 import org.bouncycastle.openpgp.PGPUserAttributeSubpacketVector;
 import org.bouncycastle.openpgp.operator.bc.BcKeyFingerprintCalculator;
-import org.bouncycastle.openpgp.operator.bc.BcPGPContentSignerBuilder;
 import org.bouncycastle.openpgp.operator.jcajce.JcaKeyFingerprintCalculator;
 import org.bouncycastle.openpgp.operator.jcajce.JcaPGPContentSignerBuilder;
 import org.bouncycastle.openpgp.operator.jcajce.JcaPGPContentVerifierBuilderProvider;
@@ -90,6 +89,7 @@ import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.OGPGPKey;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
+import com.openexchange.guard.keymanagement.commons.exceptions.KeysExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
@@ -144,6 +144,9 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                 if (keyMapping.isLocal()) {
                     GuardKeyService keyService = Services.getService(GuardKeyService.class);
                     GuardKeys key = keyService.getKeys(keyMapping.getEmail(), keyMapping.getKeyId());
+                    if (key == null) {
+                        return null;
+                    }
                     return key.getPGPPublicKeyRing();
                 }
             }
@@ -170,6 +173,9 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                 if (keyMapping.isLocal()) {
                     GuardKeyService keyService = Services.getService(GuardKeyService.class);
                     GuardKeys key = keyService.getKeys(keyMapping.getEmail(), keyMapping.getKeyId());
+                    if (key == null) {
+                        return null;
+                    }
                     return key.getPGPPublicKeyRing();
                 }
             }
@@ -368,9 +374,11 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                 publicKeyRing = PGPPublicKeyRing.insertPublicKey(publicKeyRing, key);
             }
         }
-        for (Iterator<PGPPublicKey> it2 = secretKeyRing.getExtraPublicKeys(); it2.hasNext();) {
-            PGPPublicKey key = it2.next();
-            PGPPublicKeyRing.insertPublicKey(publicKeyRing, key);
+        if (publicKeyRing != null) {
+            for (Iterator<PGPPublicKey> it2 = secretKeyRing.getExtraPublicKeys(); it2.hasNext();) {
+                PGPPublicKey key = it2.next();
+                PGPPublicKeyRing.insertPublicKey(publicKeyRing, key);
+            }
         }
         return publicKeyRing;
     }
@@ -384,37 +392,18 @@ public class PGPKeyServiceImpl implements PGPKeyService {
     public GuardKeys revokePGPPublicKeys(GuardKeys keys, String password, String reason) throws OXException {
         try {
             PGPSecretKey secretKey = keys.getPGPSecretKey();
-            Iterator<PGPPublicKey> pkeys = keys.getPGPPublicKeyRing().getPublicKeys();
-            PGPPublicKey master = secretKey.getPublicKey();
-            while (pkeys.hasNext()) {
-                PGPPublicKey pub = pkeys.next();
-                keys.setPGPPublicKeyRing(PGPPublicKeyRing.removePublicKey(keys.getPGPPublicKeyRing(), pub));
-                PGPSignatureSubpacketGenerator subHashGenerator = new PGPSignatureSubpacketGenerator();
-                PGPSignatureSubpacketGenerator subUnHashGenerator = new PGPSignatureSubpacketGenerator();
-                PGPSignatureGenerator generator = new PGPSignatureGenerator(new BcPGPContentSignerBuilder(pub.getAlgorithm(), org.bouncycastle.openpgp.PGPUtil.SHA1));
-                PGPPrivateKey priv = PGPUtil.decodePrivate(secretKey, password, keys.getSalt());
-                if (pub.isMasterKey()) {
-                    generator.init(PGPSignature.KEY_REVOCATION, priv);
-                    master = pub;
-                } else {
-                    generator.init(PGPSignature.SUBKEY_REVOCATION, priv);
-                }
-                subHashGenerator.setSignatureCreationTime(false, new Date());
-                subHashGenerator.setRevocationReason(false, revokeReason(reason), reason);
-                subUnHashGenerator.setRevocationKey(false, pub.getAlgorithm(), pub.getFingerprint());
-                generator.setHashedSubpackets(subHashGenerator.generate());
-                generator.setUnhashedSubpackets(subUnHashGenerator.generate());
-                if (pub.isMasterKey()) {
-                    PGPSignature signature = generator.generateCertification(pub);
-                    pub = PGPPublicKey.addCertification(pub, signature);
-                } else {
-                    PGPSignature signature = generator.generateCertification(master, pub);
-                    pub = PGPPublicKey.addCertification(pub, signature);
-                }
-
-                keys.setPGPPublicKeyRing(PGPPublicKeyRing.insertPublicKey(keys.getPGPPublicKeyRing(), pub));
+            if (secretKey == null) {
+                throw KeysExceptionCodes.REVOKE_FAILED.create("No secret key");
             }
-
+            PGPPrivateKey priv = PGPUtil.decodePrivate(secretKey, password, keys.getSalt());
+            if (priv == null) {
+                throw KeysExceptionCodes.REVOKE_FAILED.create("Bad password");
+            }
+            PGPPublicKeyRing newRing = PGPKeysUtil.revokeKey(priv, keys.getPGPPublicKeyRing(), 0, reason);
+            if (newRing == null) {
+                throw KeysExceptionCodes.REVOKE_FAILED.create("Failed.");
+            }
+            keys.setPGPPublicKeyRing(newRing);
             return keys;
         } catch (PGPException e) {
             throw PGPKeyExceptionCodes.PGP_ERROR.create(e, e.getMessage());
@@ -552,6 +541,10 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                     KeySignatureVerificationResult result = new KeySignatureVerificationResult("", signature.getSignatureType(), uid);
                     results.add(result);
                     return (results);
+                } else {
+                    KeySignatureVerificationResult result = new KeySignatureVerificationResult("", -1, uid);
+                    results.add(result);
+                    return (results);
                 }
             } catch (PGPException e) {
                 throw PGPKeyExceptionCodes.PGP_ERROR.create(e, e.getMessage());
@@ -587,8 +580,11 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                 try {
                     if (signature.verifyCertification(id, publicKey)) {
                         KeySignatureVerificationResult result = new KeySignatureVerificationResult("image", signature.getSignatureType(), uid);
-                        result.setImageType(id.getImageAttribute().getType());
-                        result.setImage(id.getImageAttribute().getImageData());
+                        ImageAttribute attr = id.getImageAttribute();
+                        if (attr != null) {
+                            result.setImageType(attr.getType());
+                            result.setImage(attr.getImageData());
+                        }
                         results.add(result);
                         verified = true;
                     }
