@@ -75,7 +75,7 @@ import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.translation.GuardTranslationService;
-import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.timer.TimerService;
 
@@ -94,7 +94,7 @@ public class GuardKeyServicesActivator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] { GuardConfigurationService.class, GuardDatabaseService.class, GuardShardingService.class, GuardCipherFactoryService.class,
-            GuardUserService.class, MailCreatorService.class, TimerService.class, GuardNotificationService.class, EmailStorage.class, GuardRatifierService.class,
+            OXUserService.class, MailCreatorService.class, TimerService.class, GuardNotificationService.class, EmailStorage.class, GuardRatifierService.class,
             GuardTranslationService.class, DeletedKeysStorage.class, KeyCacheStorage.class, KeyTableStorage.class,
             OGPGPKeysStorage.class, PGPKeysStorage.class, HKPClientService.class,GuardMasterKeyService.class, GuardKeyService.class, KeyCreationService.class };
     }
