@@ -64,6 +64,7 @@ import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProductName;
 import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.translation.ConditionalVissibleTemplateTransformation;
 import com.openexchange.guard.translation.GuardTranslationService;
@@ -116,6 +117,9 @@ public class MailCreatorServiceImpl implements MailCreatorService {
         transformations.add(new ConditionalVissibleTemplateTransformation("!guestmessage", guestmessage != null && !guestmessage.isEmpty()));
         GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
         String content = translationService.getTranslation(template, lang, templId, transformations);
+        if (content == null) {
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create("Missing email template");
+        }
         content = setProductName (content, host, userid, cid);
         if (content == null) {
             return (null);
@@ -164,7 +168,7 @@ public class MailCreatorServiceImpl implements MailCreatorService {
         if (type == RecipientType.BCC) {
             return (addBCC(mail, name, email));
         }
-        return (null);
+        return (mail);
     }
 
     // Add flattened to address to mail
@@ -294,6 +298,9 @@ public class MailCreatorServiceImpl implements MailCreatorService {
 
         GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
         String templ = translationService.getTranslation(templateName, lang, templId, transformations);
+        if (templ == null) {
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create("Password email template not found");
+        }
         templ = templ.replace("$from", sendername != null ? sendername : from2);
         templ = templ.replace("$password", password);
         templ = templ.replace("$plaintext", guestmessage);
