@@ -98,9 +98,9 @@ public class GuardMaintenanceMBeanImpl extends StandardMBean implements GuardMai
     }
 
     @Override
-    public void upgrade(String email) throws MBeanException {
+    public void upgrade(String email, String userid, String cid) throws MBeanException {
         try {
-            maintenanceService.upgrade(email);
+            maintenanceService.upgrade(email, userid, cid);
         } catch (OXException e) {
             throw new MBeanException(e);
         }
@@ -121,7 +121,7 @@ public class GuardMaintenanceMBeanImpl extends StandardMBean implements GuardMai
             JsonObject test = maintenanceService.test(email).get(email).getAsJsonObject();
             return new TestUserResultImpl(test.get("uid").getAsInt(),
                 test.get("cid").getAsInt(),
-                test.get("user").getAsJsonObject().get("displayName").getAsString(),
+                test.get("user").getAsJsonObject().has("displayName") ? test.get("user").getAsJsonObject().get("displayName").getAsString() : "",
                 test.get("user").getAsJsonObject().get("language").getAsString());
         } catch (OXException e) {
             throw new MBeanException(e);
@@ -146,6 +146,28 @@ public class GuardMaintenanceMBeanImpl extends StandardMBean implements GuardMai
         }
     }
 
+    @Override
+    public void importPublic (String file) throws MBeanException {
+        try {
+            maintenanceService.importPublic(file);
+        } catch (OXException e) {
+            throw new MBeanException(e);
+        }
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.management.maintenance.GuardMaintenanceMBean#repair()
+     */
+    @Override
+    public StringBuilder repair(boolean dryRun) throws MBeanException {
+        try {
+            return maintenanceService.repair(dryRun);
+        } catch (OXException e) {
+            throw new MBeanException(e);
+        }
+
+    }
+
     /* (non-Javadoc)
      * @see com.openexchange.guard.management.maintenance.GuardMaintenanceMBean#changeUser(java.lang.String, java.lang.String, int, int)
      */
