@@ -172,6 +172,9 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
     private void doSigning (OutputStream output, int userId, int contextId, String password, GuardParsedMimeMessage msg) throws Exception {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         GuardKeys key = keyService.getKeys(userId, contextId);
+        if (key == null) {
+            throw MimeEncryptorExceptionCodes.SEND_UNABLE_FIND_KEYS.create("Unable to find singing keys");
+        }
         SignMime signer = new SignMime(pgpMimeService, pgpSigningService);
         output.write(signer.signMime(msg, key, password).getBytes(StandardCharsets.UTF_8));
     }
