@@ -76,6 +76,7 @@ import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.mime.encryptor.Encryptor;
+import com.openexchange.guard.mime.encryptor.exceptions.MimeEncryptorExceptionCodes;
 import com.openexchange.guard.mime.encryptor.osgi.Services;
 import com.openexchange.guard.mime.helpfiles.HelpFileService;
 import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
@@ -95,9 +96,7 @@ import com.openexchange.pgp.mail.PGPMimeService;
  */
 public class PGPGuestEncryptor extends Encryptor {
 
-    private ArrayList<RecipKey> allRecipients;
     private PGPMimeService pgpMimeService;
-    private GuardConfigurationService guardConfigurationService;
     private HelpFileService helpFileService;
     private GuardGuestService guestService;
 
@@ -113,20 +112,16 @@ public class PGPGuestEncryptor extends Encryptor {
     public PGPGuestEncryptor(PGPCryptoService pgpCryptoService,
                              PGPMimeService pgpMimeService,
                              GuardGuestService guestService,
-                             GuardConfigurationService configService,
                              HelpFileService helpFileService,
                              GuardParsedMimeMessage msg,
                              ArrayList<RecipKey> recips,
                              int userid,
                              int cid,
-                             String password,
-                             ArrayList<RecipKey> allRecipients) {
+                             String password) {
         super(pgpCryptoService, msg, recips, userid, cid, password);
         this.pgpMimeService = Objects.requireNonNull(pgpMimeService, "pgpMimeService must not be null");
-        this.allRecipients = allRecipients;
         this.guestService = guestService;
         this.helpFileService = helpFileService;
-        this.guardConfigurationService = configService;
 
     }
 
@@ -157,6 +152,9 @@ public class PGPGuestEncryptor extends Encryptor {
         MimeMessage encryptedMessage = null;
         if(msg.isSign()) {
             GuardKeys signingKey = getSigningKey();
+            if (signingKey == null) {
+                throw MimeEncryptorExceptionCodes.SEND_UNABLE_FIND_KEYS.create("Unable to find signing keys");
+            }
             PGPSecretKey pgpSigningKey = PGPKeysUtil.getSigningKey(signingKey.getPGPSecretKeyRing());
             char[] hashedPassword = CipherUtil.getSHA(password, signingKey.getSalt()).toCharArray();
             encryptedMessage = this.pgpMimeService.encryptSigned(message, pgpSigningKey, hashedPassword, toPGPPublicKeys(this.recips), helpFileService.getHelpFiles(recips));
@@ -252,8 +250,9 @@ public class PGPGuestEncryptor extends Encryptor {
 
         try {
             att.setText(new String(encrypted, "UTF-8"));
-            att.setHeader("Content-Type", "application/octet-stream");
-            att.setFileName("encrypted.asc");
+            att.setHeader("Content-Type", "mail/rfc822");
+            att.setDisposition("attachment");
+            att.setFileName("pgpMail.eml");
         } catch (MessagingException | UnsupportedEncodingException e1) {
             // TODO Auto-generated catch block
             e1.printStackTrace();
