@@ -51,6 +51,7 @@ package com.openexchange.guard.mime.encryptor.pgp.impl;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 import javax.mail.Message;
 import javax.mail.MessagingException;
@@ -178,12 +179,11 @@ public class PGPProcessMime implements ProcessMime {
             ArrayList<RecipKey> allRecipts = recipParse.getAllRecipients();
             // Handle Guests
             if (guests.size() > 0 && !msg.isDraft()) {  // Won't create guests for draft messages
-                Encryptor guestEncryptor = new PGPGuestEncryptor(pgpCryptoService, pgpMimeService, guestService, guardConfigurationService, helpFileService, msg, guests, userId, contextId, password, allRecipts);
+                Encryptor guestEncryptor = new PGPGuestEncryptor(pgpCryptoService, pgpMimeService, guestService, helpFileService, msg, guests, userId, contextId, password);
                 if (!guestEncryptor.doEncryptAndSend()) {
                     throw MimeEncryptorExceptionCodes.SEND_EMAIL_ERROR.create("Unable to send Guest emails");
                 }
             }
-
             // Verify sender is Guest guest user, and change userid/cid to guard user
             if (msg.senderIsGuest()) {
                 Email emailResult = emailStorage.getByEmail(msg.getFromAddress().getAddress());
@@ -219,7 +219,7 @@ public class PGPProcessMime implements ProcessMime {
                     send(encryptedResult, msg.getSenderEmail(), contextId, recips, msg.getSenderIP());
 
                     //Remove the all recipients handled by Guard
-                    return convertToString(removeRecipients(encryptedResult,recips, origMessageID));
+                    return convertToString(removeRecipients(encryptedResult, allRecipts, origMessageID));
                 }
 
                 //Just remove the guests handled by Guard
@@ -265,6 +265,9 @@ public class PGPProcessMime implements ProcessMime {
     private void checkGuestSendOK(int userid, int contextId, String msgRef, ArrayList<RecipKey> recipients) throws OXException {
         if (msgRef != null) {
             GuardGuestEmailMetadata meta = guardMetaDataService.get(contextId, userid, msgRef);
+            if (meta == null) {
+                throw MimeEncryptorExceptionCodes.RECIPIENTS_NOT_IN_ORIGINAL_CHAIN.create("Unable to retrieve original meta data");
+            }
             String[] metaTos = ArrayUtils.addAll(
                 meta.getTo(),
                 ArrayUtils.addAll(meta.getCc(), meta.getFrom()));
