@@ -308,7 +308,7 @@ public class SignMime {
         ByteArrayOutputStream out = new ByteArrayOutputStream();
         message.writeTo(out);
         out.close();
-        return (out.toString());
+        return (out.toString("UTF-8"));
     }
 
     private String getMessageContentForSigning(MimeMessage message) throws IOException, MessagingException {
@@ -324,7 +324,7 @@ public class SignMime {
         ByteArrayOutputStream out = new ByteArrayOutputStream();
         msg.writeTo(out, new String[] { "Message-ID", "MIME-Version" });
         out.close();
-        return (out.toString());
+        return (out.toString("UTF-8"));
     }
 
     private String getPlainText(String html) {
