@@ -206,7 +206,7 @@ public class PGPInlineDecryptor extends Decryptor {
                 data = stripHTML (data);
             }
             data = data + "\r";
-            ByteArrayInputStream in = new ByteArrayInputStream(data.getBytes());
+            ByteArrayInputStream in = new ByteArrayInputStream(data.getBytes(StandardCharsets.UTF_8));
             PGPDecryptionResult result = pgpCryptoService.decrypt(
                 new FilteringStream(in, new FilteringStream.PrintableFilter()),
                 decryptedContent, userIdentity);
@@ -261,6 +261,7 @@ public class PGPInlineDecryptor extends Decryptor {
      * @return
      */
     private String stripHTML (String data) {
+        if (data == null) return null;
         data = data.substring(data.indexOf(BEGIN_PGP_MESSAGE_MARKER));
         data = data.substring(0, data.indexOf(END_PGP_MESSAGE_MARKER) + END_PGP_MESSAGE_MARKER.length());
         data = data.replaceAll("\r<br>", "\r").replaceAll("<br>\r", "\r").replaceAll("<br>", "\r");
