@@ -152,13 +152,16 @@ public class PGPEncryptedAttachmentManager {
                         // decode attachment here
                         GuardKeyService keyService = Services.getService(GuardKeyService.class);
                         GuardKeys key = keyService.getKeys(msg.getSenderUserId(), msg.getSenderContextId());
+                        if (key == null) {
+                            throw MimeEncryptorExceptionCodes.PROBLEM_DECODING.create("Unable to retrieve keys");
+                        }
                         PGPCryptoService cryptoService = Services.getService(PGPCryptoService.class);
                         ByteArrayOutputStream decoded = new ByteArrayOutputStream();
                         UserIdentity ident = new UserIdentity(key.getEmail(), password).setOXGuardUser(new OXGuardUser(key.getUserid(), key.getContextid()));
                         try {
                             cryptoService.decrypt((InputStream) bp.getContent(), decoded, ident);
                             if (decoded.size() > 0) {
-                                String filename = bp.getFileName().replaceAll(".pgp", "");
+                                String filename = bp.getFileName().replaceAll("\\.pgp", "");
                                 bp.setFileName(filename);
                                 bp.setContent(decoded.toByteArray(), FileTyper.getFileType(filename));
                             }
