@@ -63,6 +63,7 @@ import com.openexchange.guard.mime.encryptor.pgp.impl.HTMLStripper;
 import com.openexchange.guard.pgp.signing.impl.SignatureResults;
 import com.openexchange.guard.pgpcore.services.PGPMimeCryptoService;
 import com.openexchange.guard.pgpcore.services.PGPMimeDecryptionResult;
+import com.openexchange.guard.pgpcore.services.FromHeaderVerifier;
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 
@@ -141,6 +142,7 @@ public class PGPMimeDecryptor extends Decryptor {
             final PGPMimeDecryptionResult decryptionResult = pgpMimeCryptoService.decrypt(message, userIdentity);
             final MimeMessage decodedMsg = decryptionResult.getMimeMessage();
             final List<PGPSignatureVerificationResult> decrypt = decryptionResult.getSignatureVerificationResults();
+            FromHeaderVerifier.verify(message, decrypt);
             checkMissingHeaders(message, decodedMsg);
             if (!decryptionResult.getMDCVerifiacionResult().isPresent()) {
                 if (guardConfigService.getBooleanProperty(GuardProperty.failForMissingMDC)) {
