@@ -51,13 +51,14 @@ package com.openexchange.guard.mime.services;
 
 import java.io.UnsupportedEncodingException;
 import javax.mail.Address;
+import javax.mail.Message.RecipientType;
 import javax.mail.MessagingException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeMessage;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import javax.mail.Message.RecipientType;
+import com.openexchange.exception.OXException;
 
 /**
  * {@link GuardParsedMimeMessage}
@@ -73,17 +74,19 @@ public class GuardParsedMimeMessage {
     private final MimeParser mime;
     private final int senderUserId;
     private final int senderContextId;
+    private String senderSessionId;
     private final String fromName;
     private final boolean draft;
     private final String host;
+    private String senderEmail;
+    private boolean senderIsGuest;
     private String senderIp;
 
-
-    public GuardParsedMimeMessage (String msg, String json, int userid, int cid, String fromName, String host) throws UnsupportedEncodingException, MessagingException, JSONException {
-        this (msg, json, userid, cid, fromName, false, host);
+    public GuardParsedMimeMessage (String msg, String json, int userid, int cid, String fromName, String host, String senderEmail, boolean senderIsGuest) throws UnsupportedEncodingException, MessagingException, JSONException {
+        this (msg, json, userid, cid, fromName, false, host, senderEmail, senderIsGuest);
     }
 
-    public GuardParsedMimeMessage (String msg, JSONObject json, int userid, int cid, String fromName, boolean draft, String host) throws UnsupportedEncodingException, MessagingException, JSONException {
+    public GuardParsedMimeMessage (String msg, JSONObject json, int userid, int cid, String fromName, boolean draft, String host, String senderEmail, boolean senderIsGuest) throws UnsupportedEncodingException, MessagingException, JSONException {
         this.mime = new MimeParser(msg.getBytes("UTF-8"));
         this.msg = this.mime.getMessage();
         if (json != null) {
@@ -97,6 +100,9 @@ public class GuardParsedMimeMessage {
             } else {
                 this.recipients = new JSONArray();
             }
+            if(json.has("senderSessionId")) {
+                this.senderSessionId = json.getString("senderSessionId");
+            }
             if (json.has("senderIp")) {
                 this.senderIp = json.getString("senderIp");
             } else {
@@ -108,10 +114,12 @@ public class GuardParsedMimeMessage {
         this.fromName = fromName;
         this.draft = draft;
         this.host = host;
+        this.senderEmail = senderEmail;
+        this.senderIsGuest = senderIsGuest;
     }
 
-    public GuardParsedMimeMessage (String msg, String json, int userid, int cid, String fromName, boolean draft, String host) throws UnsupportedEncodingException, MessagingException, JSONException {
-        this(msg, json != null ? new JSONObject(json) : null, userid, cid, fromName, draft, host);
+    public GuardParsedMimeMessage (String msg, String json, int userid, int cid, String fromName, boolean draft, String host, String senderEmail, boolean senderIsGuest) throws UnsupportedEncodingException, MessagingException, JSONException {
+        this(msg, json != null ? new JSONObject(json) : null, userid, cid, fromName, draft, host, senderEmail, senderIsGuest);
     }
 
     public void setMessage(MimeMessage msg) {
@@ -198,6 +206,10 @@ public class GuardParsedMimeMessage {
         return this.senderContextId;
     }
 
+    public String getSenderSessionId() {
+        return this.senderSessionId;
+    }
+
     /**
      * Parse the from address from message header
      * @return
@@ -261,22 +273,70 @@ public class GuardParsedMimeMessage {
     public RecipientType getRecipType (String email) {
         try {
             String [] toHeaders = this.msg.getHeader("To");
-            for (String to : toHeaders) {
-                if (to.toLowerCase().contains(email.toLowerCase())) {
-                    return RecipientType.TO;
+            if(toHeaders != null) {
+                for (String to : toHeaders) {
+                    if (to.toLowerCase().contains(email.toLowerCase())) {
+                        return RecipientType.TO;
+                    }
                 }
             }
+
             String [] ccHeaders = this.msg.getHeader("Cc");
-            for (String cc : ccHeaders) {
-                if (cc.toLowerCase().contains(email.toLowerCase())) {
-                    return RecipientType.CC;
+            if(ccHeaders != null) {
+                for (String cc : ccHeaders) {
+                    if (cc.toLowerCase().contains(email.toLowerCase())) {
+                        return RecipientType.CC;
+                    }
                 }
             }
-            return RecipientType.BCC;
+
+            String[] bcHeaders = this.msg.getHeader("Bc");
+            if(bcHeaders != null) {
+                for (String bc : bcHeaders) {
+                    if (bc.toLowerCase().contains(email.toLowerCase())) {
+                        return RecipientType.BCC;
+                    }
+                }
+            }
+            return null;
         } catch (MessagingException e) {
             return null;
         }
+    }
 
+    /**
+     * Gets the sender's email
+     *
+     * @return The sender's email
+     */
+    public String getSenderEmail() {
+        return this.senderEmail;
+    }
+
+    /**
+     * Parse the headers for the message reference of original Guest email
+     * @return
+     * @throws OXException
+     */
+    public String getGuardMessagRef () throws OXException {
+        String[] refs;
+        try {
+            refs = msg.getHeader("X-Guard-msg-ref");
+            if (refs != null && refs.length > 0) {
+                return refs[0];
+            }
+        } catch (MessagingException e) {
+            throw OXException.general("Problem parsing msg header for Guard reference", e);
+        }
+        return null;
+    }
+    /**
+     * Gets the guest status of the sender
+     *
+     * @return The guest status of the sender
+     */
+    public boolean senderIsGuest() {
+        return senderIsGuest;
     }
 
     public String getSenderIP() {
