@@ -208,7 +208,7 @@ public class MimeParser {
     public static String getBoundry(final MimeMessage msg) throws MessagingException {
         try {
             final String[] content = msg.getHeader("Content-Type");
-            if (content.length > 0) {
+            if (content != null && content.length > 0) {
                 final int i = content[0].indexOf("boundary");
                 if (i > 0) {
                     String bndry = content[0].substring(i);
