@@ -102,10 +102,6 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
         return hasUserId(key.getUserIDs(), userIdentity);
     }
 
-    private boolean hasUserId(PGPPublicKey key, String userIdentity) {
-        return hasUserId(key.getUserIDs(), userIdentity);
-    }
-
     /**
      * Retrieves Guard Key information for a given key id
      *
@@ -117,6 +113,18 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
         return guardKeyService.getKeys(keyId);
     }
 
+    /**
+     * Retrieves Guard key information for a given key id belonging to a user
+     *
+     * @param keyId The ID of the key
+     * @param userIdentity The user's identity
+     * @return The GuardKey for the given key id and userIdentity, or null if not key was found
+     * @throws OXException
+     */
+    private GuardKeys getGuardKeyByIdForUserIdentity(long keyId, String userIdentity) throws OXException {
+        return guardKeyService.getKeysBySubKeyId(userIdentity, keyId);
+    }
+
     /**
      * Extracts a private key from a PGPSecretKey object
      *
@@ -152,7 +160,7 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
      */
     @Override
     public PGPPrivateKey getSecretKey(long keyId, String userIdentity, char[] password) throws Exception {
-        GuardKeys guardKeys = getGuardKeyById(keyId);
+        GuardKeys guardKeys = userIdentity != null ? getGuardKeyByIdForUserIdentity(keyId, userIdentity) : getGuardKeyById(keyId);
         if (guardKeys != null) {
             PGPSecretKeyRing pgpSecretKeyRing = guardKeys.getPGPSecretKeyRing();
             if (pgpSecretKeyRing == null) {
@@ -166,7 +174,6 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
                 }
                 else {
                     //Check if we find the userIdentity within the key, or master-key
-
                     if(userIdentity.contains(guardKeys.getEmail()) || hasUserId(secretKey,userIdentity) || hasUserId(pgpSecretKeyRing.getSecretKey()/*masterKey*/,userIdentity)) {
                         return decodePrivateKey(secretKey, hashPassword(password,guardKeys.getSalt()));
                     }
