@@ -2,7 +2,6 @@
 package com.openexchange.guard.pgpcore.services.impl.osgi;
 
 import com.openexchange.exception.OXException;
-import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
@@ -10,18 +9,25 @@ import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
 import com.openexchange.guard.pgpcore.services.GuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
+import com.openexchange.guard.pgpcore.services.PGPKeySigningService;
+import com.openexchange.guard.pgpcore.services.PGPMimeCryptoService;
+import com.openexchange.guard.pgpcore.services.PGPPacketService;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.pgpcore.services.impl.CompositeGuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.impl.DBKeyRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.impl.EmailGuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.impl.PGPCryptoServiceImpl;
+import com.openexchange.guard.pgpcore.services.impl.PGPKeySigningServiceImpl;
+import com.openexchange.guard.pgpcore.services.impl.PGPMimeCryptoServiceImpl;
+import com.openexchange.guard.pgpcore.services.impl.PGPPacketServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.PGPSigningServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.TokenAuthenticationServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.UserIDGuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.session.GuardSessionService;
-import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
 
 public class PGPCoreServicesImplActivator extends HousekeepingActivator {
 
@@ -43,7 +49,7 @@ public class PGPCoreServicesImplActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { GuardCipherFactoryService.class, GuardKeyService.class, GuardSessionService.class, GuardUserService.class, OGPGPKeysStorage.class};
+        return new Class<?>[] { GuardCipherFactoryService.class, GuardKeyService.class, GuardSessionService.class, OXUserService.class, OGPGPKeysStorage.class};
     }
 
     /**
@@ -56,17 +62,23 @@ public class PGPCoreServicesImplActivator extends HousekeepingActivator {
         //Key retrieval strategies
         GuardKeyRingRetrievalStrategy guardKeyRingRetrievalStrategy = new CompositeGuardKeyRingRetrievalStrategy(new EmailGuardKeyRingRetrievalStrategy(getService(GuardKeyService.class)), new UserIDGuardKeyRingRetrievalStrategy(getService(GuardKeyService.class)));
         PGPKeyRetrievalStrategy pgpKeyRetrievalStrategy = new DBKeyRetrievalStrategy(getService(GuardKeyService.class));
+
+        //create pgp crypto service
+        PGPCryptoServiceImpl pgpCryptoService = new PGPCryptoServiceImpl(guardKeyRingRetrievalStrategy,
+                                                                         getService(GuardKeyService.class),
+                                                                         getService(OGPGPKeysStorage.class));
+
         //Register the services
         registerService(TokenAuthenticationService.class,
             new TokenAuthenticationServiceImpl(guardKeyRingRetrievalStrategy,
                                                getService(GuardSessionService.class),
                                                getCipherService(),
-                                               getService(GuardUserService.class)));
-        registerService(PGPCryptoService.class,
-            new PGPCryptoServiceImpl(guardKeyRingRetrievalStrategy,
-                getService(GuardKeyService.class),
-                getService(OGPGPKeysStorage.class)));
+                                               getService(OXUserService.class)));
+        registerService(PGPCryptoService.class, pgpCryptoService);
+        registerService(PGPMimeCryptoService.class, new PGPMimeCryptoServiceImpl(pgpCryptoService));
         registerService(PGPSigningService.class, new PGPSigningServiceImpl(guardKeyRingRetrievalStrategy, pgpKeyRetrievalStrategy));
+        registerService(PGPPacketService.class, new PGPPacketServiceImpl());
+        registerService(PGPKeySigningService.class, new PGPKeySigningServiceImpl(pgpKeyRetrievalStrategy));
     }
 
     /**
@@ -78,6 +90,8 @@ public class PGPCoreServicesImplActivator extends HousekeepingActivator {
         unregisterService(TokenAuthenticationService.class);
         unregisterService(PGPCryptoService.class);
         unregisterService(PGPSigningService.class);
+        unregisterService(PGPPacketService.class);
+        unregisterService(PGPKeySigningService.class);
         super.stopBundle();
     }
 }
