@@ -59,14 +59,24 @@ import com.openexchange.i18n.LocalizableStrings;
  */
 public final class PGPCoreServicesExceptionMessages implements LocalizableStrings {
 
+    // Unable to retrieve recipients key, with specified key id(s)
     public static final String RECIPIENT_KEY_NOT_FOUND = "Unable to retrieve recipient's key (%1$s)";
+    // Unable to retrieve signing key, with key Ids or email addresses in variable
     public static final String SIGNING_KEY_NOT_FOUND = "Unable to retrieve signing key (%1$s)";
+    // Encryption error with error appended
     public static final String ENCRYPTION_ERROR = "An PGP encryption error occured: %1$s";
+    // Decryption error with error appended
     public static final String DECRYPTION_ERROR = "An PGP decryption error occured: %1$s";
+    // Signing error with error appended
     public static final String SIGNING_ERROR = "An PGP signing error occured: %1$s";
+    // Signature verification error with error appended
     public static final String SIGNATURE_VERIFICATION_ERROR = "An PGP signature verification error occured: %1$s";
+    // Unexpected error with error appended
     public static final String UNEXPECTED_ERROR = "Unexpected error occured: %1$s";
+    // Unable to parse recipient address(es)
     public static final String RECIPIENT_PARSING_ERROR = "Unable to parse the given recipient (%1$s)";
+    // The email message is not a proper multipart message (type of email)
+    public static final String NOT_A_MULTIPART_MSG_ERROR = "The provided message is not a proper multipart message";
 
     private PGPCoreServicesExceptionMessages() {}
 }
