@@ -87,4 +87,11 @@ public interface GuardRatifierService {
      * @return ipAddress if valid, null if not or local IP address
      */
     String verifyRemoteIP(String ipAddress);
+
+    /**
+     * @param email
+     * @return true if valid email address
+     */
+    boolean isValid(String email);
+
 }
