@@ -6,7 +6,7 @@ import com.openexchange.i18n.LocalizableStrings;
 public class GuardRatifierExceptionMessages implements LocalizableStrings {
 
     /** Returned (for multiple actions) when an invalid email address has been provided */
-    public static final String INVALID_EMAIL_ADDRESS_MSG = "The provided email address is not valid.";
+    public static final String INVALID_EMAIL_ADDRESS_MSG = "The given Email address %1$s is invalid";
 
     private GuardRatifierExceptionMessages() {
         super();
