@@ -99,12 +99,12 @@ public class GuardRatifierServiceImpl implements GuardRatifierService {
     }
 
     @Override
-    public void validate(String email) throws OXException {
+    public boolean isValid(String email) {
         if (Strings.isEmpty(email)) {
-            throw GuardRatifierExceptionCodes.INVALID_EMAIL_ADDRESS.create(email);
+            return false;
         }
         if (!email.contains("@")) {
-            throw GuardRatifierExceptionCodes.INVALID_EMAIL_ADDRESS.create(email);
+            return false;
         }
         try {
             String aceConformMailAddress = IDNA.toACE(new String(email));
@@ -112,6 +112,14 @@ public class GuardRatifierServiceImpl implements GuardRatifierService {
             e.validate();
         } catch (AddressException e) {
             logger.warn("{}", e);
+            return false;
+        }
+        return true;
+    }
+
+    @Override
+    public void validate(String email) throws OXException {
+        if (!isValid(email)) {
             throw GuardRatifierExceptionCodes.INVALID_EMAIL_ADDRESS.create(email);
         }
     }
@@ -149,9 +157,10 @@ public class GuardRatifierServiceImpl implements GuardRatifierService {
             String first = m.group(1);
             String second = m.group(2);
             int secondInt = 0;
-            if (second != null) {
-                secondInt = Integer.parseInt(second);
+            if (second == null) {
+                return null;
             }
+            secondInt = Integer.parseInt(second);
             if (ipAddress.equals("127.0.0.1")) return null;  // Localhost
             // Check IP4 local addresses
             if (first.equals("10") ||
