@@ -249,37 +249,43 @@ public class GuardTranslationServiceImpl implements GuardTranslationService {
             List<String> lines = Files.readAllLines(path, StandardCharsets.UTF_8);
             for (int i = 0; i < lines.size(); i++) {
                 if (lines.get(i).contains("msgid")) { // First message ID line
-                    String id = getBetweenQuotes(lines.get(i));
+                    StringBuilder sb = new StringBuilder();
+                    sb.append(getBetweenQuotes(lines.get(i)));
                     i++;
                     String line2 = lines.get(i);
                     while (line2.trim().startsWith("\"")) {
-                        id = id + getBetweenQuotes(line2);
+                        sb.append(getBetweenQuotes(line2));
                         i++;
                         line2 = lines.get(i);
                     }
+                    String id = sb.toString();
                     ArrayList<String> plurals = new ArrayList<String>();
-                    if (line2.contains("msgid_plural")) {// Pleural based field
-                        String plural = getBetweenQuotes(line2);
-                        i++;
-                        while (lines.get(i).contains("msgstr")) {
-                            plurals.add(getBetweenQuotes(lines.get(i)));
+                    if (!id.isEmpty()) {
+                        if (line2.contains("msgid_plural")) {// Pleural based field
+                            String plural = getBetweenQuotes(line2);
                             i++;
-                        }
-                        Translation trans = new Translation(id, plural, plurals);
-                        mapping.put(id, trans);
-                        mapping.put(plural, trans);
-                    } else {
-                        // Singular based field
-                        String data = lines.get(i);
-                        if (data.contains("msgstr")) {
-                            String transl = getBetweenQuotes(data);
-
-                            while (((i + 1) < lines.size()) && lines.get(i + 1).trim().startsWith("\"")) {
+                            while (lines.get(i).contains("msgstr")) {
+                                plurals.add(getBetweenQuotes(lines.get(i)));
                                 i++;
-                                transl = transl + getBetweenQuotes(lines.get(i));
                             }
-                            Translation trans = new Translation(id, transl);
+                            Translation trans = new Translation(id, plural, plurals);
                             mapping.put(id, trans);
+                            mapping.put(plural, trans);
+                        } else {
+                            // Singular based field
+                            String data = lines.get(i);
+                            if (data.contains("msgstr")) {
+                                StringBuilder trsb = new StringBuilder();
+                                trsb.append(getBetweenQuotes(data));
+
+                                while (((i + 1) < lines.size()) && lines.get(i + 1).trim().startsWith("\"")) {
+                                    i++;
+                                    trsb.append(getBetweenQuotes(lines.get(i)));
+                                }
+                                String transl = trsb.toString();
+                                Translation trans = new Translation(id, transl);
+                                mapping.put(id, trans);
+                            }
                         }
                     }
                 }
