@@ -59,8 +59,8 @@ import com.openexchange.pgp.keys.common.PGPSymmetricKey;
  */
 public class UserIdentity {
 
-    private final String    identity;
     private final char[]    password;
+    private String          identity;
     private PGPSymmetricKey symmetricKey;
     private OXUser          oxUser;
     private OXGuardUser     oxGuardUser;
@@ -95,6 +95,17 @@ public class UserIdentity {
         return identity;
     }
 
+    /**
+     * Sets the identity
+     *
+     * @param identity The identity to set
+     * @return this
+     */
+    public UserIdentity setIdentity(String identity) {
+        this.identity = identity;
+        return this;
+    }
+
     /**
      * Gets the password
      *
