@@ -49,6 +49,7 @@
 
 package com.openexchange.guard.demo;
 
+import java.util.List;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
@@ -85,6 +86,40 @@ public class DemoUtil {
         }
     }
 
+    /**
+     * Internal method to delete a user's Guard key by email
+     *
+     * @param email The emai object of the user
+     * @throws OXException
+     */
+    private void deleteByEmail(Email email) throws OXException {
+        if (email != null) {
+            int userId = email.getUserId();
+            int contextId = email.getContextId();
+            new UserDeleter().delete(userId, contextId);
+        } else {
+            throw DemoExceptionCodes.UNKNOWN_EMAIL_ERROR.create(email);
+        }
+    }
+
+    /**
+     * Deletes all known OX Guard keys  WITHOUT creating any backups
+     * (com.openexchange.guard.demo has to be "true")
+     * @throws OXException
+     */
+    public int deleteAllUserKeys() throws OXException {
+        assertDemoMode();
+
+        EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
+        List<Email> allEmails = ogEmailStorage.getEmails();
+        int count = 0;
+        for(Email email : allEmails) {
+            deleteByEmail(email);
+            count++;
+        }
+        return count;
+    }
+
     /**
      * Deletes all known OX Guard keys for a given email WITHOUT creating any backups
      * (com.openexchange.guard.demo has to be "true")
@@ -97,12 +132,11 @@ public class DemoUtil {
         assertDemoMode();
 
         EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
-        Email ogEmail = ogEmailStorage.getByEmail(email);
-        if (ogEmail != null) {
-            int userId = ogEmail.getUserId();
-            int contextId = ogEmail.getContextId();
-            new UserDeleter().delete(userId, contextId);
-        } else {
+        Email emailObject = ogEmailStorage.getByEmail(email);
+        if(emailObject != null) {
+            deleteByEmail(emailObject);
+        }
+        else {
             throw DemoExceptionCodes.UNKNOWN_EMAIL_ERROR.create(email);
         }
     }
