@@ -104,7 +104,7 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
         JsonObject userdat;
         try {
             userdat = mailResolver.resolveUser(mail);
-            if (userdat.has(mail)) {
+            if (userdat != null && userdat.has(mail)) {
                 return userdat;
             } else {
                 throw GuardMaintenanceExceptionCodes.UNABLE_TO_RESOLVE_MAIL_ADDRESS.create(mail);
@@ -196,6 +196,9 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
         // 2.10 and post
         EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
         Email ogEmail = ogEmailStorage.getByEmail(mail);
+        if (ogEmail == null) {
+            throw GuardMaintenanceExceptionCodes.ACCOUNT_NOT_FOUND.create(mail);
+        }
         SecondFactorService secondFactor = Services.getService(SecondFactorService.class);
         secondFactor.removeSecondFactor(ogEmail.getUserId(), ogEmail.getContextId());
     }
