@@ -52,7 +52,7 @@ package com.openexchange.guard.pgp;
 import java.util.List;
 import com.google.gson.JsonObject;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
-import com.openexchange.guard.mail.Attachment;
+import com.openexchange.guard.mime.services.Attachment;
 import com.openexchange.guard.oxapi.OxCookie;
 
 /**
