@@ -54,6 +54,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
+import java.nio.charset.StandardCharsets;
 import java.security.SignatureException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -235,19 +236,21 @@ public class PGPPublicHandler {
         boolean added = false;
         for (int j = 0; j < ids.size(); j++) {
             InternetAddress addr = parseEmailAdress(ids.get(j).getAsString());
-            try {
-                addr.validate();
-            } catch (Exception e) {
-                continue;
+            if (addr != null) {
+                try {
+                    addr.validate();
+                } catch (Exception e) {
+                    continue;
+                }
+                String email = IDNUtil.decodeEmail(addr.getAddress());
+
+                //Adding the new uploaded key to the storage
+                String asciiData = KeyExportUtil.export(ring);
+                OGPGPKeysStorage ogpgpKeysStorage = Services.getService(OGPGPKeysStorage.class);
+                ogpgpKeysStorage.insertOrUpdate(userid, cid, email, keyhexids, asciiData);
+
+                added = true;
             }
-            String email = IDNUtil.decodeEmail(addr.getAddress());
-
-            //Adding the new uploaded key to the storage
-            String asciiData = KeyExportUtil.export(ring);
-            OGPGPKeysStorage ogpgpKeysStorage = Services.getService(OGPGPKeysStorage.class);
-            ogpgpKeysStorage.insertOrUpdate(userid, cid, email, keyhexids, asciiData);
-
-            added = true;
         }
         return added;
     }
@@ -291,7 +294,7 @@ public class PGPPublicHandler {
             try(ApiResponse plainAttachment = ap.getPlainAttachment(emailid, attach, folder)){
                 Attachment att = new Attachment();
                 att.setContent(plainAttachment.readContent());
-                data = new String(att.getContent());
+                data = new String(att.getContent(), StandardCharsets.UTF_8);
             }
         } else {
             // Handle encrypted public key
@@ -447,7 +450,7 @@ public class PGPPublicHandler {
             ret.add(jsonKey);
         }
 
-        if (emailArray.size() > 0) {
+        if ((emailArray != null) && (emailArray.size() > 0)) {
             GuardKeyService keyService = Services.getService(GuardKeyService.class);
             for (int i = 0; i < emailArray.size(); i++) {
                 String email = emailArray.get(i);
