@@ -9,6 +9,7 @@ import java.io.StringReader;
 import java.io.UnsupportedEncodingException;
 import java.net.URLEncoder;
 import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
@@ -448,7 +449,7 @@ public class PGPSender {
                 if (draft) {
                     LOG.debug("Saving draft to " + mail.getDraftFolder());
                 }
-                resp = ap.sendMimeMail(out.toString(), draft ? mail.getDraftFolder() : null);
+                resp = ap.sendMimeMail(out.toString("UTF-8"), draft ? mail.getDraftFolder() : null);
                 if (Utilities.checkFail(resp)) {
                     return ("fail " + JsonUtil.getError(resp));
                 }
@@ -493,7 +494,7 @@ public class PGPSender {
         for (Attachment attachment : attachments) {
             try {
                 final BodyPart att = new MimeBodyPart();
-                att.setText(new String(attachment.getEncrContent()));
+                att.setText(new String(attachment.getEncrContent(), StandardCharsets.UTF_8));
                 att.setHeader("Content-Type", Strings.removeCarriageReturn(attachment.getType()));
                 att.setFileName(Strings.removeCarriageReturn(attachment.getFilename()));
 
@@ -556,7 +557,7 @@ public class PGPSender {
         msg.saveChanges();
         ByteArrayOutputStream out = new ByteArrayOutputStream();
         msg.writeTo(out);
-        ap.sendMimeMail(out.toString(), ap.getSentFolder());
+        ap.sendMimeMail(out.toString("UTF-8"), ap.getSentFolder());
     }
 
     private void addDraftHeaders(JsonObject data, Message newMessage) throws MessagingException {
@@ -737,7 +738,7 @@ public class PGPSender {
                             PGPUtils.encrypt(encrypted, content.getBytes("UTF-8"), "encrypted.asc", inlineRecip, true, true);
                         }
                         attach.remove("content");
-                        String encr = encrypted.toString();
+                        String encr = encrypted.toString("UTF-8");
                         encrypted.close();
                         String type = attach.get("content_type").getAsString();
                         if (type.contains("altern") || type.contains("html")) {
