@@ -58,6 +58,7 @@ import java.nio.charset.StandardCharsets;
 import java.security.NoSuchProviderException;
 import java.security.SecureRandom;
 import java.security.SignatureException;
+import java.util.ArrayList;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
@@ -108,7 +109,9 @@ import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
+import com.openexchange.guard.pgpcore.services.FromHeaderVerifier;
 import com.openexchange.guard.session.GuardSessionService;
+import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 public class PGPUtils {
@@ -322,6 +325,43 @@ public class PGPUtils {
         return result;
     }
 
+    /**
+     * Verify the from address is in the list of userIds for the public keys
+     * @param result
+     * @param keyring
+     * @param fromAddress
+     * @return
+     */
+    private PGPResult verifyFrom(PGPResult result, PGPPublicKeyRing keyring, String fromAddress) {
+        if (!result.isVerified()) {
+            return result;
+        }
+        if (fromAddress == null || fromAddress.isEmpty()) {
+            result.setVerified(false);
+            result.setError("Unable to verify due to missing FROM address");
+            return result;
+        }
+        ArrayList<String> userIds = new ArrayList<String>();
+        Iterator<PGPPublicKey> keys = keyring.getPublicKeys();
+        while (keys.hasNext()) {
+            PGPPublicKey key = (PGPPublicKey) keys.next();
+            Iterator ids = key.getUserIDs();
+            while (ids.hasNext()) {
+                userIds.add((String) ids.next());
+            }
+        }
+        Iterator ids = userIds.iterator();
+        while (ids.hasNext()) {
+            String id = (String) ids.next();
+            if (id.toLowerCase().contains(fromAddress.toLowerCase())) return result;
+
+        }
+        result.setVerified(false);
+        result.setError("The issuer of the signature was not found in the FROM header for the MIME message.");
+        return result;
+
+    }
+
     /**
      * Verify signature in inline signature
      *
@@ -388,12 +428,13 @@ public class PGPUtils {
             } else {
                 result.setVerified(false);
             }
+            result = verifyFrom(result, pgpRing, fromAddress);
 
         } else {
             result.setSignature(false);
             // no signature
         }
-        return (result);
+        return result;
     }
 
     /**
@@ -489,7 +530,7 @@ public class PGPUtils {
         } else {
             result.setVerified(false);
         }
-        return (result);
+        return (verifyFrom(result, pgpRing, fromAddress));
 
     }
 
@@ -723,7 +764,9 @@ public class PGPUtils {
         } catch (OXException ex) {
             throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
         }
-
+        if (pgpSignKey == null) {
+            throw GuardPGPExceptionCodes.SENDER_KEYS_MISSING.create();
+        }
         sgen.init(PGPSignature.BINARY_DOCUMENT, pgpSignKey);
 
         BCPGOutputStream bout = new BCPGOutputStream(out);
