@@ -74,35 +74,6 @@ public class PgpHandler {
 
     private static Logger LOG = LoggerFactory.getLogger(PgpHandler.class);
 
-    /**
-     * Return JsonArray of info for PGPSecretKeyRing
-     *
-     * @param skeyring
-     * @return
-     */
-    public static JsonArray getPrivateInfo(PGPSecretKeyRing skeyring) {
-        if (skeyring == null) {
-            return (null);
-        }
-        Iterator skeys = skeyring.getSecretKeys();
-        JsonArray keyRingData = new JsonArray();
-        while (skeys.hasNext()) {
-            PGPSecretKey key = (PGPSecretKey) skeys.next();
-            JsonObject pubKey = new JsonObject();
-            pubKey.addProperty("Key", LongUtil.longToHexStringTruncated(key.getKeyID()));
-            pubKey.addProperty("KeyID", LongUtil.longToHexString(key.getKeyID()));
-            pubKey.addProperty("Master", key.isMasterKey());
-            Iterator it = key.getUserIDs();
-            JsonArray ids = new JsonArray();
-            while (it.hasNext()) {
-                ids.add(new JsonPrimitive((String) it.next()));
-            }
-            pubKey.add("ids", ids);
-            keyRingData.add(pubKey);
-        }
-        return (keyRingData);
-    }
-
     /**
      * Print the user info for a PGP public key ring with userid escaped for display
      * @param pkey
@@ -114,6 +85,74 @@ public class PgpHandler {
         return getKeyInfo(pkey, true);
     }
 
+    public static JsonObject getKeyInfo (PGPPublicKey key, boolean htmlSafe) {
+        JsonObject pubKey = new JsonObject();
+        pubKey.addProperty("Key", LongUtil.longToHexStringTruncated(key.getKeyID()));
+        pubKey.addProperty("KeyID", LongUtil.longToHexString(key.getKeyID()));
+        pubKey.addProperty("KeyLong", Long.toString(key.getKeyID()));
+        pubKey.addProperty("Fingerprint", PGPKeysUtil.getFingerPrintInBlocks(key.getFingerprint()));
+        pubKey.addProperty("Created", key.getCreationTime().toString());
+        pubKey.addProperty("Master", key.isMasterKey());
+        pubKey.addProperty("Encryption", PGPKeysUtil.isEncryptionKey(key));
+        pubKey.addProperty("Revoked", key.hasRevocation());
+        boolean expired = false;
+        long validSeconds = key.getValidSeconds();
+        if (validSeconds != 0) {  // 0 expiration time means doesn't expire
+            Date now = new Date();
+            long timeLeft = key.getCreationTime().getTime() + (validSeconds * 1000) - now.getTime();
+            if (timeLeft < 0) {
+                expired = true;
+            } else {
+                pubKey.addProperty("Expires", timeLeft / 86400000);  // Number of days left
+            }
+        } else {
+            pubKey.addProperty("Expires", "never");
+        }
+        pubKey.addProperty("Expired", expired);
+        Iterator it = key.getUserIDs();
+        int i = 0;
+        JsonArray ids = new JsonArray();
+        while (it.hasNext()) {
+            if (htmlSafe) {
+                String htmlEscapedId = org.apache.commons.lang.StringEscapeUtils.escapeHtml((String) it.next());
+                ids.add(new JsonPrimitive(htmlEscapedId));
+            } else {
+                ids.add(new JsonPrimitive((String) it.next()));
+            }
+        }
+        pubKey.add("ids", ids);
+        Iterator<PGPUserAttributeSubpacketVector> im = key.getUserAttributes();
+        int imagecount = 0;
+        JsonArray images = new JsonArray();
+        while (im.hasNext()) {
+            PGPUserAttributeSubpacketVector vector = im.next();
+            ImageAttribute image = vector.getImageAttribute();
+            if (image != null) {
+                JsonObject imageJson = new JsonObject();
+                imageJson.add("type", new JsonPrimitive(image.getType()));
+                if (image.getType() == 1) {
+                    imageJson.addProperty("data", "data:image/jpg;base64," + Base64.encodeBase64String(image.getImageData()));
+                }
+                imageJson.add("index", new JsonPrimitive(imagecount));
+                imageJson.addProperty("keyid", Long.toString(key.getKeyID()));
+                imagecount++;
+                images.add(imageJson);
+            }
+
+        }
+        pubKey.add("images", images);
+        it = key.getSignatures();
+        i = 0;
+        while (it.hasNext()) {
+            PGPSignature sig = (PGPSignature) it.next();
+            String sigid = LongUtil.longToHexStringTruncated(sig.getKeyID());
+            //  if (!sigid.equals(self)) {
+            pubKey.addProperty(i++ + "-" + PGPUtil.getSignatureType(sig.getSignatureType()) + "- Signed by", sigid);
+            //  }
+        }
+        return(pubKey);
+    }
+
     /**
      * Print the user info for a PGP public key ring. Returns as JSON
      *
@@ -128,71 +167,7 @@ public class PgpHandler {
         PGPPublicKey key = null;
         while (keys.hasNext()) {
             key = keys.next();
-            JsonObject pubKey = new JsonObject();
-            pubKey.addProperty("Key", LongUtil.longToHexStringTruncated(key.getKeyID()));
-            pubKey.addProperty("KeyID", LongUtil.longToHexString(key.getKeyID()));
-            pubKey.addProperty("KeyLong", Long.toString(key.getKeyID()));
-            pubKey.addProperty("Fingerprint", PGPKeysUtil.getFingerPrintInBlocks(key.getFingerprint()));
-            pubKey.addProperty("Created", key.getCreationTime().toString());
-            pubKey.addProperty("Master", key.isMasterKey());
-            pubKey.addProperty("Encryption", PGPKeysUtil.isEncryptionKey(key));
-            pubKey.addProperty("Revoked", key.hasRevocation());
-            boolean expired = false;
-            long validSeconds = key.getValidSeconds();
-            if (validSeconds != 0) {  // 0 expiration time means doesn't expire
-                Date now = new Date();
-                long timeLeft = key.getCreationTime().getTime() + (validSeconds * 1000) - now.getTime();
-                if (timeLeft < 0) {
-                    expired = true;
-                } else {
-                    pubKey.addProperty("Expires", timeLeft / 86400000);  // Number of days left
-                }
-            } else {
-                pubKey.addProperty("Expires", "never");
-            }
-            pubKey.addProperty("Expired", expired);
-            Iterator it = key.getUserIDs();
-            int i = 0;
-            JsonArray ids = new JsonArray();
-            while (it.hasNext()) {
-                if (htmlSafe) {
-                    String htmlEscapedId = org.apache.commons.lang.StringEscapeUtils.escapeHtml((String) it.next());
-                    ids.add(new JsonPrimitive(htmlEscapedId));
-                } else {
-                    ids.add(new JsonPrimitive((String) it.next()));
-                }
-            }
-            pubKey.add("ids", ids);
-            Iterator<PGPUserAttributeSubpacketVector> im = key.getUserAttributes();
-            int imagecount = 0;
-            JsonArray images = new JsonArray();
-            while (im.hasNext()) {
-                PGPUserAttributeSubpacketVector vector = im.next();
-                ImageAttribute image = vector.getImageAttribute();
-                if (image != null) {
-                    JsonObject imageJson = new JsonObject();
-                    imageJson.add("type", new JsonPrimitive(image.getType()));
-                    if (image.getType() == 1) {
-                        imageJson.addProperty("data", "data:image/jpg;base64," + Base64.encodeBase64String(image.getImageData()));
-                    }
-                    imageJson.add("index", new JsonPrimitive(imagecount));
-                    imageJson.addProperty("keyid", Long.toString(key.getKeyID()));
-                    imagecount++;
-                    images.add(imageJson);
-                }
-
-            }
-            pubKey.add("images", images);
-            it = key.getSignatures();
-            i = 0;
-            while (it.hasNext()) {
-                PGPSignature sig = (PGPSignature) it.next();
-                String sigid = LongUtil.longToHexStringTruncated(sig.getKeyID());
-                //	if (!sigid.equals(self)) {
-                pubKey.addProperty(i++ + "-" + PGPUtil.getSignatureType(sig.getSignatureType()) + "- Signed by", sigid);
-                //	}
-            }
-            keyRingData.add(pubKey);
+            keyRingData.add(getKeyInfo(key, htmlSafe));
         }
         return (keyRingData);
 
