@@ -65,39 +65,39 @@ import com.openexchange.exception.OXExceptionStrings;
 public enum GuardPGPExceptionCodes implements DisplayableOXExceptionCode {
 
     /** Unable to retrieve sender keys. */
-    SENDER_KEYS_MISSING("Unable to retrieve sender keys.", CATEGORY_ERROR, 1),
+    SENDER_KEYS_MISSING("Unable to retrieve sender keys.", GuardPGPExceptionMessages.SENDER_KEYS_MISSING_MSG, CATEGORY_ERROR, 1),
 
-    SEND_FAILED("Sending email failed: %1$s", CATEGORY_ERROR, 2),
+    SEND_FAILED("Sending email failed: %1$s",GuardPGPExceptionMessages.SEND_FAILED_MSG, CATEGORY_ERROR, 2),
 
-    ENCODING_NOT_SUPPORTED("The provided encoding is not supported.", CATEGORY_ERROR, 3),
+    ENCODING_NOT_SUPPORTED("The provided encoding is not supported.",GuardPGPExceptionMessages.ENCODING_NOT_SUPPORTED_MSG, CATEGORY_ERROR, 3),
 
-    MAIL_CONSTRUCTION_ERROR("Error while creating the encrypted mail.", CATEGORY_ERROR, 4),
+    MAIL_CONSTRUCTION_ERROR("Error while creating the encrypted mail.",GuardPGPExceptionMessages.MAIL_CONSTRUCTION_ERROR_MSG, CATEGORY_ERROR, 4),
 
     BAD_PASSWORD_ERROR("Provided password is not correct.", GuardPGPExceptionMessages.BAD_PASSWORD_ERROR_MSG, CATEGORY_USER_INPUT, 5),
 
-    IO_ERROR("An I/O error occurred: %1$s", Category.CATEGORY_ERROR, 6),
+    IO_ERROR("An I/O error occurred: %1$s", GuardPGPExceptionMessages.IO_ERROR_MSG, Category.CATEGORY_ERROR, 6),
 
-    SIGNATURE_ERROR_NO_SIGNED_DATA("No signed data found in E-Mail", Category.CATEGORY_ERROR, 7),
+    SIGNATURE_ERROR_NO_SIGNED_DATA("No signed data found in E-Mail", GuardPGPExceptionMessages.SIGNATURE_ERROR_NO_SIGNED_DATA_MSG, Category.CATEGORY_ERROR, 7),
 
-    SIGNATURE_ERROR_NO_SIGNATURE("No signature found in E-Mail", Category.CATEGORY_ERROR, 8),
+    SIGNATURE_ERROR_NO_SIGNATURE("No signature found in E-Mail", GuardPGPExceptionMessages.SIGNATURE_ERROR_NO_SIGNATURE_MSG, Category.CATEGORY_ERROR, 8),
 
-    SIGNATURE_ERROR_NO_SIGNED_MESSAGE_FOUND("No signed message found in inline E-Mail", Category.CATEGORY_ERROR, 9),
+    SIGNATURE_ERROR_NO_SIGNED_MESSAGE_FOUND("No signed message found in inline E-Mail", GuardPGPExceptionMessages.SIGNATURE_ERROR_NO_SIGNED_MESSAGE_FOUND_MSG, Category.CATEGORY_ERROR, 9),
 
-    MIME_NOT_MULTIPART_ERROR("The Mime message's content is not a MultiPart content", Category.CATEGORY_ERROR, 10),
+    MIME_NOT_MULTIPART_ERROR("The Mime message's content is not a MultiPart content", GuardPGPExceptionMessages.MIME_NOT_MULTIPART_ERROR_MSG, Category.CATEGORY_ERROR, 10),
 
-    MIME_NO_GUARDPART_ERROR("The MIME message does not contain an OX Guard part", CATEGORY_ERROR, 11),
+    MIME_NO_GUARDPART_ERROR("The MIME message does not contain an OX Guard part", GuardPGPExceptionMessages.MIME_NO_GUARDPART_ERROR_MSG, CATEGORY_ERROR, 11),
 
-    MIME_ATTACHMENT_NOT_FOUND("No attachment found in MIME with name %1$s", CATEGORY_ERROR, 12),
+    MIME_ATTACHMENT_NOT_FOUND("No attachment found in MIME with name %1$s", GuardPGPExceptionMessages.MIME_ATTACHMENT_NOT_FOUND_MSG, CATEGORY_ERROR, 12),
 
-    MIME_ATTACHMENT_ID_NOT_FOUND("No attachment found in MIME with id %1$s", CATEGORY_ERROR, 13),
+    MIME_ATTACHMENT_ID_NOT_FOUND("No attachment found in MIME with id %1$s", GuardPGPExceptionMessages.MIME_ATTACHMENT_ID_NOT_FOUND_MSG, CATEGORY_ERROR, 13),
 
-    UNEXPECTED_ERROR("An error occurred: %1$s", Category.CATEGORY_ERROR, 14),
+    UNEXPECTED_ERROR("An error occurred: %1$s", GuardPGPExceptionMessages.UNEXPECTED_ERROR_MSG, Category.CATEGORY_ERROR, 14),
 
-    UNABLE_TO_DECODE("Unable to decode pgp key for user %1$s in context %2$s.", Category.CATEGORY_ERROR, 15),
+    UNABLE_TO_DECODE("Unable to decode pgp key for user %1$s in context %2$s.", GuardPGPExceptionMessages.UNABLE_TO_DECODE_MSG, Category.CATEGORY_ERROR, 15),
 
-    KEY_NOT_FOUND("Key not found with id %1$s",Category.CATEGORY_ERROR,16),
+    KEY_NOT_FOUND("Key with id %1$s not found", GuardPGPExceptionMessages.KEY_NOT_FOUND_MSG,Category.CATEGORY_ERROR,16),
 
-    NO_VALID_KEY("There were no valid public keys found.  Either the keys are expired, or not flagged for this action.", GuardPGPExceptionMessages.NO_VALID_PUBLIC_KEYS_FOUND, Category.CATEGORY_ERROR, 17),
+    NO_VALID_KEY("There were no valid public keys found.  Either the keys are expired, or not flagged for this action.", GuardPGPExceptionMessages.NO_VALID_PUBLIC_KEYS_FOUND_MSG, Category.CATEGORY_ERROR, 17),
 
     ;
 
