@@ -53,6 +53,7 @@ import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.nio.charset.StandardCharsets;
 import java.security.SignatureException;
 import java.util.Properties;
 import java.util.regex.Matcher;
@@ -244,7 +245,7 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
         }
         String ret = data;
         try {
-            ret = new String(Base64.decode(data.trim()));
+            ret = new String(Base64.decode(data.trim()), StandardCharsets.UTF_8);
         } catch (Exception e) {
             LOG.error("Problem decoding Base64 attachment", e);
         }
@@ -540,7 +541,7 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
                                     bp.setContent(getContentInlineBody((String) bp.getContent(), false), bp.getContentType());
                                     newpart.addBodyPart(bp);
                                 } else {
-                                    if (bp.getContentType().contains("text/plain")) {  // If the plaintext fails, we'll just fail the entire thing and return original message
+                                    if (bp.getContentType() != null && bp.getContentType().toLowerCase().contains("text/plain")) {  // If the plaintext fails, we'll just fail the entire thing and return
                                         msg.saveChanges();
                                         return msg;
                                     }
