@@ -65,6 +65,7 @@ public class SignatureResults {
     private static final String VERIFIED_PROPERTY = "verified";
     private static final String DATE_PROPERTY = "signatureCreatedOn";
     private static final String MISSING_PROPERTY = "missing";
+    private static final String ERROR_PROPERTY = "error";
 
 
     public static String[] toHeaders (List<PGPSignatureVerificationResult> results) {
@@ -93,6 +94,8 @@ public class SignatureResults {
         sb.append(result.isVerified() ? "true" : "false");
         sb.append("; " + MISSING_PROPERTY + "=");
         sb.append(result.isMissingPublicKey() ? "true" : "false");
+        sb.append("; " + ERROR_PROPERTY + "=");
+        sb.append(result.getError());
         return sb.toString();
     }
 }
