@@ -58,8 +58,11 @@ import org.json.JSONObject;
 import com.openexchange.antiabuse.AllowParameters;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
+import com.openexchange.guard.auth.AuthUtils;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
@@ -69,7 +72,6 @@ import com.openexchange.guard.keymanagement.commons.antiabuse.UserAntiAbuseWrapp
 import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.logging.GuardLogProperties;
 import com.openexchange.guard.osgi.Services;
-import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.servlets.authentication.AuthenticationDataExtractor;
 import com.openexchange.guard.servlets.authentication.GuardAuthenticationHandler;
@@ -176,6 +178,18 @@ public abstract class GuardServletAction {
         return true;
     }
 
+    private GuardUserSession getSession(HttpServletRequest request) throws OXException {
+        GuardUserSession guardUserSession = new GuestSessionValidator().validateSession(request);
+        if (guardUserSession == null) {
+            guardUserSession = new RestSessionValidator().validateSession(request);
+            logAction(request, guardUserSession);
+        }
+        else {
+            logGuestAction(request, guardUserSession);
+        }
+        return guardUserSession;
+    }
+
     /**
      * Performs the action after checking the authentication
      *
@@ -185,20 +199,22 @@ public abstract class GuardServletAction {
      */
     public void doAction(HttpServletRequest request, HttpServletResponse response) throws Exception {
         //Validate session if provided by the client and get corresponding context-id and user-id
-        GuardUserSession guardUserSession = new GuestSessionValidator().validateSession(request);
-        if (guardUserSession == null) {
-            guardUserSession = new RestSessionValidator().validateSession(request);
-            logAction(request, guardUserSession);
-        }
-        else {
-            logGuestAction(request, guardUserSession);
-        }
-
+        GuardUserSession guardUserSession = getSession(request);
         //authenticate
         if (doAuthentication(request, guardUserSession, response)) {
             doActionInternal(request, response, guardUserSession);
         }
         else {
+            if (guardUserSession == null) {  // If authentication failed, and no user session
+                GuardConfigurationService guardConfig = Services.getService(GuardConfigurationService.class);
+                Thread.sleep(guardConfig.getIntProperty(GuardProperty.sessionSyncDelay), 3000);
+                guardUserSession = getSession(request);  // Try again.  Hazelcast delay or sync issues
+                if (doAuthentication(request, guardUserSession, response)) {
+                    LOG.warn("Validated session only after delay.  Verify routing from Guard to middleware");
+                    doActionInternal(request, response, guardUserSession);
+                    return;
+                }
+            }
             ServletUtils.sendResponse(response, HttpServletResponse.SC_UNAUTHORIZED, "Unauthorized");
         }
     }
@@ -350,6 +366,17 @@ public abstract class GuardServletAction {
         return requireOrReturn(userIdentity, require);
     }
 
+    /**
+     * Gets a {@link UserIdentity} from the given {@link GuardUserSession}
+     *
+     * @param guardUserSession The user session
+     * @return The {@link UserIdentity} from the given {@link GuardUserSession}
+     * @throws OXException
+     */
+    protected UserIdentity getUserIdentityFrom(GuardUserSession guardUserSession) throws OXException {
+        return AuthUtils.getUserIdentityFrom(guardUserSession);
+    }
+
     /**
      * Template method which allows implementation of the action execution by subclasses
      *
