@@ -178,7 +178,7 @@ public class Guest {
                     return;
                 }
             }
-            String senderIp = (request == null ? null: request.getRemoteAddr());
+            String senderIp = request.getRemoteAddr();
             reset(email, lang, templId, cid, userid, request.getServerName(), senderIp);
 
             antiabuse.removeBad(email);
