@@ -50,18 +50,13 @@
 package com.openexchange.guard.servlets.guest;
 
 import java.io.InputStream;
-
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-
 import com.google.gson.JsonObject;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
-import com.openexchange.guard.encryption.EncryptedItem;
-import com.openexchange.guard.encryption.EncryptedItemAccess;
-import com.openexchange.guard.encryption.EncryptedItemsStorage;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.inputvalidation.EmailValidator;
@@ -83,7 +78,7 @@ import com.openexchange.guard.storage.Storage;
  * @since v7.8.3
  */
 public class GuestFirstPasswordAction extends GuardServletAction {
-	
+
     /**
      * For a guest users first access, change temporary password saved in recovery
      */
@@ -136,25 +131,21 @@ public class GuestFirstPasswordAction extends GuardServletAction {
 
         // Here, let's verify the itemId exists
         Storage storage = Services.getService(Storage.class);
-        try(InputStream in = storage.readObj(keys.getUserid(), keys.getContextid(), itemId);){
+        try(InputStream in = storage.readObj(itemId);){
             if (in == null) {
                 antiabuse.addBad(ip);
                 throw GuestServletExceptionCodes.BAD_EMAIL_ID.create();
             }
         }
 
-        //..and verify that the item belongs to the user
-        EncryptedItemsStorage itemStorage = Services.getService(EncryptedItemsStorage.class);
-        String rawItemId = itemId.substring("pgp-".length());
-        EncryptedItem encryptedItem = itemStorage.getById(rawItemId, keys.getUserid(), keys.getContextid());
-        if(encryptedItem == null || !EncryptedItemAccess.verifyAccess(encryptedItem, keys.getUserid(), keys.getContextid())) {
-        	throw GuestServletExceptionCodes.BAD_EMAIL_ID.create();
-        }
-		
         // OK, verified.  Let's change the password
         PasswordChangeService passService = Services.getService(PasswordChangeService.class);
         OxCookie cookie = new OxCookie(request.getCookies());
-        String retJson = passService.changePassword(keys.getUserid(), keys.getContextid(), email, "", newpass, question, answer, cookie.getOxReaderID());
+        String retJson = passService.changePassword(keys.getUserid(), keys.getContextid(), email, "", newpass, question, answer, pin, cookie.getOxReaderID());
         ServletUtils.sendOK(response, "application/json", retJson);
+
+
+
     }
+
 }
