@@ -103,10 +103,10 @@ public class KeymanagementServlet extends AbstractGuardServlet {
     private static final String ADD_USER_ID = "addUserId";
     private static final String REVOKE_KEY = "revoke";
     private static final String GET_SIGNATURES = "getSignatures";
-    private final HashMap<String, GuardServletAction> getActions;
-    private final HashMap<String, GuardServletAction> postActions;
-    private final HashMap<String, GuardServletAction> putActions;
-    private final HashMap<String, GuardServletAction> deleteActions;
+    private transient final HashMap<String, GuardServletAction> getActions;
+    private transient final HashMap<String, GuardServletAction> postActions;
+    private transient final HashMap<String, GuardServletAction> putActions;
+    private transient final HashMap<String, GuardServletAction> deleteActions;
 
     /**
      * Initializes a new {@link KeymanagementServlet}.
