@@ -68,6 +68,7 @@ import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseWrapper;
 import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.responses.BinaryResponse;
+import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link DownloadKeyAction}
@@ -87,14 +88,14 @@ public class DownloadKeyAction extends GetKeyAction {
      * @throws Exception
      */
     private InputStream exportPrivateKey(GuardUserSession userSession, HttpServletRequest request, final GuardKeys keys)  throws Exception {
-        final String password = ServletUtils.getStringParameter(request, Parameters.PARAM_PASSWORD, true);
-        final AntiAbuseWrapper antiAbuseWrapper = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), password));
+        final UserIdentity userIdentity = requireUserIdentityFrom(request);
+        final AntiAbuseWrapper antiAbuseWrapper = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), new String(userIdentity.getPassword())));
         return antiAbuseWrapper.doAction(new AntiAbuseAction<InputStream>() {
 
             @Override
             public InputStream doAction() throws Exception {
                 return new ByteArrayInputStream(
-                    KeyExportUtil.exportPGPPrivateKey(keys, password).getBytes(StandardCharsets.UTF_8));
+                    KeyExportUtil.exportPGPPrivateKey(keys, new String(userIdentity.getPassword())).getBytes(StandardCharsets.UTF_8));
             }
         });
     }
@@ -109,14 +110,14 @@ public class DownloadKeyAction extends GetKeyAction {
      * @throws OXException
      */
     private InputStream exportPublicAndPrivateKey(GuardUserSession userSession, HttpServletRequest request, final GuardKeys keys) throws Exception {
-        final String password = ServletUtils.getStringParameter(request, Parameters.PARAM_PASSWORD, true);
-        final AntiAbuseWrapper antiAbuseWrapper = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), password));
+        final UserIdentity userIdentity = requireUserIdentityFrom(request);
+        final AntiAbuseWrapper antiAbuseWrapper = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), new String(userIdentity.getPassword())));
         return antiAbuseWrapper.doAction(new AntiAbuseAction<InputStream>() {
 
             @Override
             public InputStream doAction() throws Exception {
                 return new ByteArrayInputStream(
-                    KeyExportUtil.exportPGPPublicAndPrivateKey(keys, password).getBytes(StandardCharsets.UTF_8));
+                    KeyExportUtil.exportPGPPublicAndPrivateKey(keys, new String(userIdentity.getPassword())).getBytes(StandardCharsets.UTF_8));
             }
         });
     }
