@@ -58,9 +58,11 @@ import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.fileupload.FileItem;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.bouncycastle.openpgp.PGPSecretKeyRing;
+import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.inputvalidation.EmailValidator;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.services.KeyImportService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
@@ -68,6 +70,7 @@ import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
+import com.openexchange.guard.servlets.keymanagement.responses.GuardKeyInfoCollectionResponse;
 import com.openexchange.pgp.keys.parsing.KeyRingParserResult;
 import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 
@@ -84,6 +87,27 @@ public class UploadKeysAction extends GuardServletAction {
     private static final String KEY_PASSWORD_PARAMETER_NAME = "keyPassword";
     private static final String NEW_PASSWORD_PARAMETER_NAME = "newPassword";
 
+    /**
+     * Internal method to remove duplicated key rings
+     *
+     * @param importedKeyRings The list of keys rings
+     * @return The list where duplicates have been removed
+     */
+    private Collection<GuardKeys> removeDuplicatedImportedKeyResults(Collection<GuardKeys> importedKeyRings) {
+
+        Collection<GuardKeys> ret = new ArrayList<GuardKeys>(importedKeyRings.size());
+        Collection<Long> recognizedIds = new ArrayList<Long>(importedKeyRings.size());
+
+        importedKeyRings.forEach(key -> {
+            if(!recognizedIds.contains(new Long(key.getPGPPublicKey().getKeyID()))){
+                recognizedIds.add(new Long(key.getPGPPublicKey().getKeyID()));
+                ret.add(key);
+            }
+        });
+
+        return ret;
+    }
+
     /* (non-Javadoc)
      * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
      */
@@ -128,26 +152,33 @@ public class UploadKeysAction extends GuardServletAction {
         //Check if password parameters are present when importing secret keys
         if(parsedSecretKeyRings.size() > 0) {
             if(keyPassword == null || keyPassword.isEmpty()) {
-                throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(KEY_PASSWORD_PARAMETER_NAME);
+                parsedSecretKeyRings.clear();
             }
-            if(newPassword == null || newPassword.isEmpty()) {
+            if(!parsedSecretKeyRings.isEmpty() && (newPassword == null || newPassword.isEmpty())) {
                 throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(NEW_PASSWORD_PARAMETER_NAME);
             }
         }
 
         //Import parsed keys
         KeyImportService keyImportService = Services.getService(KeyImportService.class);
-        keyImportService.importPrivateKeyRing(userSession.getUserId(),
-            userSession.getContextId(),
+        Collection<GuardKeys> importedKeyRings = keyImportService.importPrivateKeyRing(userSession.getGuardUserId(),
+            userSession.getGuardContextId(),
             email,
             userSession.getLocale(),
             keyPassword,
             newPassword,
             parsedSecretKeyRings.toArray(new PGPSecretKeyRing[parsedSecretKeyRings.size()]));
-        keyImportService.importPublicKeyRing(userSession.getUserId(),
-            userSession.getContextId(),
+        importedKeyRings.addAll(
+            keyImportService.importPublicKeyRing(userSession.getGuardUserId(),
+            userSession.getGuardContextId(),
             email,
             userSession.getLocale(),
-            parsedPublicKeyRings.toArray(new PGPPublicKeyRing[parsedPublicKeyRings.size()]));
+            parsedPublicKeyRings.toArray(new PGPPublicKeyRing[parsedPublicKeyRings.size()])));
+
+        //the result list can contain duplicates because if public + private keys are imported / merged keys are also returned.
+        //Cleaning up for a client.
+        importedKeyRings = removeDuplicatedImportedKeyResults(importedKeyRings);
+        ServletUtils.sendObject(response, new GuardKeyInfoCollectionResponse(newPassword, importedKeyRings));
     }
+
 }
