@@ -78,9 +78,9 @@ public class LoginServlet extends AbstractGuardServlet {
     private static final String DELETE_RECOVERY_ACTION = "deleterecovery";
     private static final String DELETE_SESSION = "delete_session";
 
-    private final HashMap<String, GuardServletAction> servletGetActions;
-    private final HashMap<String, GuardServletAction> servletPostActions;
-    private final HashMap<String, GuardServletAction> servletPutActions;
+    private transient final HashMap<String, GuardServletAction> servletGetActions;
+    private transient final HashMap<String, GuardServletAction> servletPostActions;
+    private transient final HashMap<String, GuardServletAction> servletPutActions;
 
     public LoginServlet(GuardAuthenticationHandler basicAuthServletAuthentication ) throws OXException {
 
