@@ -69,8 +69,8 @@ public class MailServlet extends AbstractGuardServlet {
     private static final String POST_NEW_ENCRYPTED_EMAIL_ACTION = "emailform";
 
 
-    private final HashMap<String, GuardServletAction> postActions;
-    private final HashMap<String, GuardServletAction> getActions;
+    private transient final HashMap<String, GuardServletAction> postActions;
+    private transient final HashMap<String, GuardServletAction> getActions;
 
     public MailServlet(){
         OXGuardSessionAuthenticationHandler uiSessionAuthentication = new OXGuardSessionAuthenticationHandler();
