@@ -82,8 +82,8 @@ public class PGPCoreServlet extends AbstractGuardServlet {
     private static final String POST_DELETE_AUTH_ACTION = "deleteauthtoken";
     private static final String POST_EXTRACT_ENCRYPTED_SESSION_KEY_PACKETS = "extractsessionkeys";
     private static final String POST_CHANGE_SHARING = "changeshare";
-    private final HashMap<String, GuardServletAction> postActions;
-    private final HashMap<String, GuardServletAction> putActions;
+    private transient final HashMap<String, GuardServletAction> postActions;
+    private transient final HashMap<String, GuardServletAction> putActions;
 
     /**
      * Internal method to create an authentication handler which protects the API
