@@ -3,6 +3,8 @@ package com.openexchange.guard.support;
 
 import java.util.ArrayList;
 import java.util.List;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.activity.ActivityTrackingService;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
@@ -24,6 +26,8 @@ import com.openexchange.guard.storage.cache.FileCacheStorage;
 //TODO: maybe solve with a com.openexchange.groupware.delete.DeleteListener?
 public class UserDeleter {
 
+    private static final Logger LOG = LoggerFactory.getLogger(UserDeleter.class);
+
     private void backupKeys(List<GuardKeys> keys) throws OXException {
         //Backup keys to deleted key table / backup table
         ArrayList<DeletedKey> deletedKeys = new ArrayList<DeletedKey>();
@@ -73,8 +77,12 @@ public class UserDeleter {
         Storage storage = Services.getService(Storage.class);
         List<FileCacheItem> items = fileStorage.findAllForUser(userId);
         for (FileCacheItem item: items) {
-            storage.deleteEncrObj(item.getLocation());
-            fileStorage.delete(item.getItemId());
+            try {
+                storage.deleteEncrObj(item.getLocation());
+                fileStorage.delete(item.getItemId());
+            } catch (OXException ex) {
+                LOG.error("Unable to delete Guest file ", item.getLocation());
+            }
         }
         // Remove any redirects
         GuestRedirectorService redirector = Services.getService(GuestRedirectorService.class);
